@@ -44,6 +44,7 @@ import org.apache.http.HttpResponse;
 import org.apache.http.HttpResponseInterceptor;
 import org.apache.http.HttpStatus;
 import org.apache.http.HttpVersion;
+import org.apache.http.config.ConnectionConfig;
 import org.apache.http.entity.ContentType;
 import org.apache.http.impl.DefaultConnectionReuseStrategy;
 import org.apache.http.impl.EnglishReasonPhraseCatalog;
@@ -66,27 +67,23 @@ import org.apache.http.nio.NHttpServerConnection;
 import org.apache.http.nio.entity.NStringEntity;
 import org.apache.http.nio.pool.NIOConnFactory;
 import org.apache.http.nio.protocol.BasicAsyncResponseProducer;
-import org.apache.http.nio.protocol.HttpAsyncRequestExecutor;
+import org.apache.http.nio.protocol.HttpAsyncExchange;
 import org.apache.http.nio.protocol.HttpAsyncRequestConsumer;
-import org.apache.http.nio.protocol.HttpAsyncRequester;
+import org.apache.http.nio.protocol.HttpAsyncRequestExecutor;
 import org.apache.http.nio.protocol.HttpAsyncRequestHandler;
-import org.apache.http.nio.protocol.HttpAsyncRequestHandlerRegistry;
-import org.apache.http.nio.protocol.HttpAsyncRequestHandlerResolver;
+import org.apache.http.nio.protocol.HttpAsyncRequestHandlerMapper;
 import org.apache.http.nio.protocol.HttpAsyncRequestProducer;
+import org.apache.http.nio.protocol.HttpAsyncRequester;
 import org.apache.http.nio.protocol.HttpAsyncResponseConsumer;
 import org.apache.http.nio.protocol.HttpAsyncResponseProducer;
-import org.apache.http.nio.protocol.HttpAsyncExchange;
 import org.apache.http.nio.protocol.HttpAsyncService;
+import org.apache.http.nio.protocol.UriHttpAsyncRequestHandlerMapper;
 import org.apache.http.nio.reactor.ConnectingIOReactor;
 import org.apache.http.nio.reactor.IOEventDispatch;
 import org.apache.http.nio.reactor.ListeningIOReactor;
-import org.apache.http.params.CoreConnectionPNames;
-import org.apache.http.params.CoreProtocolPNames;
-import org.apache.http.params.HttpParams;
-import org.apache.http.params.SyncBasicHttpParams;
 import org.apache.http.pool.PoolStats;
-import org.apache.http.protocol.ExecutionContext;
 import org.apache.http.protocol.HttpContext;
+import org.apache.http.protocol.HttpCoreContext;
 import org.apache.http.protocol.HttpProcessor;
 import org.apache.http.protocol.ImmutableHttpProcessor;
 import org.apache.http.protocol.RequestConnControl;
@@ -123,15 +120,11 @@ public class NHttpReverseProxy {
 
         System.out.println("Reverse proxy to " + targetHost);
 
-        HttpParams params = new SyncBasicHttpParams();
-        params
-            .setIntParameter(CoreConnectionPNames.SO_TIMEOUT, 30000)
-            .setIntParameter(CoreConnectionPNames.SOCKET_BUFFER_SIZE, 8 * 1024)
-            .setParameter(CoreProtocolPNames.ORIGIN_SERVER, "Test/1.1")
-            .setParameter(CoreProtocolPNames.USER_AGENT, "Test/1.1");
-
-        IOReactorConfig config = new IOReactorConfig();
-        config.setIoThreadCount(1);
+        IOReactorConfig config = IOReactorConfig.custom()
+            .setIoThreadCount(1)
+            .setSoTimeout(3000)
+            .setConnectTimeout(3000)
+            .build();
         final ConnectingIOReactor connectingIOReactor = new DefaultConnectingIOReactor(config);
         final ListeningIOReactor listeningIOReactor = new DefaultListeningIOReactor(config);
 
@@ -139,7 +132,7 @@ public class NHttpReverseProxy {
         HttpProcessor inhttpproc = new ImmutableHttpProcessor(
                 new HttpResponseInterceptor[] {
                         new ResponseDate(),
-                        new ResponseServer(),
+                        new ResponseServer("Test/1.1"),
                         new ResponseContent(),
                         new ResponseConnControl()
          });
@@ -150,29 +143,31 @@ public class NHttpReverseProxy {
                         new RequestContent(),
                         new RequestTargetHost(),
                         new RequestConnControl(),
-                        new RequestUserAgent(),
-                        new RequestExpectContinue()
+                        new RequestUserAgent("Test/1.1"),
+                        new RequestExpectContinue(true)
         });
 
         ProxyClientProtocolHandler clientHandler = new ProxyClientProtocolHandler();
         HttpAsyncRequester executor = new HttpAsyncRequester(
-                outhttpproc, new ProxyOutgoingConnectionReuseStrategy(), params);
+                outhttpproc, new ProxyOutgoingConnectionReuseStrategy());
 
-        ProxyConnPool connPool = new ProxyConnPool(connectingIOReactor, params);
+        ProxyConnPool connPool = new ProxyConnPool(connectingIOReactor, ConnectionConfig.DEFAULT);
         connPool.setMaxTotal(100);
         connPool.setDefaultMaxPerRoute(20);
 
-        HttpAsyncRequestHandlerRegistry handlerRegistry = new HttpAsyncRequestHandlerRegistry();
+        UriHttpAsyncRequestHandlerMapper handlerRegistry = new UriHttpAsyncRequestHandlerMapper();
         handlerRegistry.register("*", new ProxyRequestHandler(targetHost, executor, connPool));
 
         ProxyServiceHandler serviceHandler = new ProxyServiceHandler(
-                inhttpproc, new ProxyIncomingConnectionReuseStrategy(), handlerRegistry, params);
+                inhttpproc,
+                new ProxyIncomingConnectionReuseStrategy(),
+                handlerRegistry);
 
         final IOEventDispatch connectingEventDispatch = new DefaultHttpClientIODispatch(
-                clientHandler, params);
+                clientHandler, ConnectionConfig.DEFAULT);
 
         final IOEventDispatch listeningEventDispatch = new DefaultHttpServerIODispatch(
-                serviceHandler, params);
+                serviceHandler, ConnectionConfig.DEFAULT);
 
         Thread t = new Thread(new Runnable() {
 
@@ -767,7 +762,7 @@ public class NHttpReverseProxy {
         @Override
         public boolean keepAlive(final HttpResponse response, final HttpContext context) {
             NHttpConnection conn = (NHttpConnection) context.getAttribute(
-                    ExecutionContext.HTTP_CONNECTION);
+                    HttpCoreContext.HTTP_CONNECTION);
             boolean keepAlive = super.keepAlive(response, context);
             if (keepAlive) {
                 System.out.println("[client->proxy] connection kept alive " + conn);
@@ -782,7 +777,7 @@ public class NHttpReverseProxy {
         @Override
         public boolean keepAlive(final HttpResponse response, final HttpContext context) {
             NHttpConnection conn = (NHttpConnection) context.getAttribute(
-                    ExecutionContext.HTTP_CONNECTION);
+                    HttpCoreContext.HTTP_CONNECTION);
             boolean keepAlive = super.keepAlive(response, context);
             if (keepAlive) {
                 System.out.println("[proxy->origin] connection kept alive " + conn);
@@ -797,9 +792,8 @@ public class NHttpReverseProxy {
         public ProxyServiceHandler(
                 final HttpProcessor httpProcessor,
                 final ConnectionReuseStrategy reuseStrategy,
-                final HttpAsyncRequestHandlerResolver handlerResolver,
-                final HttpParams params) {
-            super(httpProcessor, reuseStrategy, handlerResolver, params);
+                final HttpAsyncRequestHandlerMapper handlerResolver) {
+            super(httpProcessor, reuseStrategy, null, handlerResolver, null);
         }
 
         @Override
@@ -849,15 +843,17 @@ public class NHttpReverseProxy {
 
     static class ProxyConnPool extends BasicNIOConnPool {
 
-        public ProxyConnPool(final ConnectingIOReactor ioreactor, final HttpParams params) {
-            super(ioreactor, params);
+        public ProxyConnPool(
+                final ConnectingIOReactor ioreactor,
+                final ConnectionConfig config) {
+            super(ioreactor, config);
         }
 
         public ProxyConnPool(
                 final ConnectingIOReactor ioreactor,
                 final NIOConnFactory<HttpHost, NHttpClientConnection> connFactory,
-                final HttpParams params) {
-            super(ioreactor, connFactory, params);
+                final int connectTimeout) {
+            super(ioreactor, connFactory, connectTimeout);
         }
 
         @Override
