@@ -285,7 +285,7 @@ public class DefaultNHttpClientConnection
     public void produceOutput(final NHttpClientEventHandler handler) {
         try {
             if (this.status == ACTIVE) {
-                if (this.contentEncoder == null) {
+                if (this.contentEncoder == null && !this.outbuf.hasData()) {
                     handler.requestReady(this);
                 }
                 if (this.contentEncoder != null) {
@@ -307,9 +307,6 @@ public class DefaultNHttpClientConnection
                     this.status = CLOSED;
                     resetOutput();
                 }
-                if (this.contentEncoder == null && this.status != CLOSED) {
-                    this.session.clearEvent(EventMask.WRITE);
-                }
             }
         } catch (final Exception ex) {
             handler.exception(this, ex);
