@@ -50,6 +50,7 @@ import org.apache.http.HttpMessage;
 import org.apache.http.HttpRequest;
 import org.apache.http.HttpResponse;
 import org.apache.http.annotation.NotThreadSafe;
+import org.apache.http.config.MessageConstraints;
 import org.apache.http.entity.BasicHttpEntity;
 import org.apache.http.entity.ContentLengthStrategy;
 import org.apache.http.impl.HttpConnectionMetricsImpl;
@@ -101,6 +102,7 @@ public class NHttpConnectionBase
     protected final SessionInputBufferImpl inbuf;
     protected final SessionOutputBufferImpl outbuf;
     private final int fragmentSizeHint;
+    private final MessageConstraints constraints;
 
     protected final HttpTransportMetricsImpl inTransportMetrics;
     protected final HttpTransportMetricsImpl outTransportMetrics;
@@ -165,6 +167,7 @@ public class NHttpConnectionBase
         this.inbuf = new SessionInputBufferImpl(buffersize, linebuffersize, decoder, allocator);
         this.outbuf = new SessionOutputBufferImpl(buffersize, linebuffersize, encoder, allocator);
         this.fragmentSizeHint = buffersize;
+        this.constraints = MessageConstraints.DEFAULT;
 
         this.incomingContentStrategy = createIncomingContentStrategy();
         this.outgoingContentStrategy = createOutgoingContentStrategy();
@@ -186,18 +189,20 @@ public class NHttpConnectionBase
      * @param buffersize buffer size. Must be a positive number.
      * @param fragmentSizeHint fragment size hint.
      * @param allocator memory allocator.
-     *   If <code>null</code> {@link org.apache.http.nio.util.HeapByteBufferAllocator#INSTANCE}
+     *   If {@code null} {@link org.apache.http.nio.util.HeapByteBufferAllocator#INSTANCE}
      *   will be used.
      * @param chardecoder decoder to be used for decoding HTTP protocol elements.
-     *   If <code>null</code> simple type cast will be used for byte to char conversion.
+     *   If {@code null} simple type cast will be used for byte to char conversion.
      * @param charencoder encoder to be used for encoding HTTP protocol elements.
-     *   If <code>null</code> simple type cast will be used for char to byte conversion.
-     * @param incomingContentStrategy incoming content length strategy. If <code>null</code>
+     *   If {@code null} simple type cast will be used for char to byte conversion.
+     * @param constraints Message constraints. If {@code null}
+     *   {@link MessageConstraints#DEFAULT} will be used.
+     * @param incomingContentStrategy incoming content length strategy. If {@code null}
      *   {@link LaxContentLengthStrategy#INSTANCE} will be used.
-     * @param outgoingContentStrategy outgoing content length strategy. If <code>null</code>
+     * @param outgoingContentStrategy outgoing content length strategy. If {@code null}
      *   {@link StrictContentLengthStrategy#INSTANCE} will be used.
      *
-     * @since 4.3
+     * @since 4.4
      */
     protected NHttpConnectionBase(
             final IOSession session,
@@ -206,6 +211,7 @@ public class NHttpConnectionBase
             final ByteBufferAllocator allocator,
             final CharsetDecoder chardecoder,
             final CharsetEncoder charencoder,
+            final MessageConstraints constraints,
             final ContentLengthStrategy incomingContentStrategy,
             final ContentLengthStrategy outgoingContentStrategy) {
         Args.notNull(session, "I/O session");
@@ -221,6 +227,7 @@ public class NHttpConnectionBase
         this.inTransportMetrics = new HttpTransportMetricsImpl();
         this.outTransportMetrics = new HttpTransportMetricsImpl();
         this.connMetrics = new HttpConnectionMetricsImpl(this.inTransportMetrics, this.outTransportMetrics);
+        this.constraints = constraints != null ? constraints : MessageConstraints.DEFAULT;
         this.incomingContentStrategy = incomingContentStrategy != null ? incomingContentStrategy :
             LaxContentLengthStrategy.INSTANCE;
         this.outgoingContentStrategy = outgoingContentStrategy != null ? outgoingContentStrategy :
@@ -230,6 +237,39 @@ public class NHttpConnectionBase
         this.status = ACTIVE;
     }
 
+    /**
+     * Creates new instance NHttpConnectionBase given the underlying I/O session.
+     *
+     * @param session the underlying I/O session.
+     * @param buffersize buffer size. Must be a positive number.
+     * @param fragmentSizeHint fragment size hint.
+     * @param allocator memory allocator.
+     *   If {@code null} {@link org.apache.http.nio.util.HeapByteBufferAllocator#INSTANCE}
+     *   will be used.
+     * @param chardecoder decoder to be used for decoding HTTP protocol elements.
+     *   If {@code null} simple type cast will be used for byte to char conversion.
+     * @param charencoder encoder to be used for encoding HTTP protocol elements.
+     *   If {@code null} simple type cast will be used for char to byte conversion.
+     * @param incomingContentStrategy incoming content length strategy. If {@code null}
+     *   {@link LaxContentLengthStrategy#INSTANCE} will be used.
+     * @param outgoingContentStrategy outgoing content length strategy. If {@code null}
+     *   {@link StrictContentLengthStrategy#INSTANCE} will be used.
+     *
+     * @since 4.3
+     */
+    protected NHttpConnectionBase(
+            final IOSession session,
+            final int buffersize,
+            final int fragmentSizeHint,
+            final ByteBufferAllocator allocator,
+            final CharsetDecoder chardecoder,
+            final CharsetEncoder charencoder,
+            final ContentLengthStrategy incomingContentStrategy,
+            final ContentLengthStrategy outgoingContentStrategy) {
+        this(session, buffersize, fragmentSizeHint, allocator, chardecoder, charencoder,
+                null, incomingContentStrategy, outgoingContentStrategy);
+    }
+
     private void setSession(final IOSession session) {
         this.session = session;
         this.context = new SessionHttpContext(this.session);
@@ -245,7 +285,6 @@ public class NHttpConnectionBase
      */
     protected void bind(final IOSession session) {
         Args.notNull(session, "I/O session");
-        this.session.setBufferStatus(null);
         setSession(session);
     }
 
@@ -291,34 +330,42 @@ public class NHttpConnectionBase
         return new HttpConnectionMetricsImpl(inTransportMetric, outTransportMetric);
     }
 
+    @Override
     public int getStatus() {
         return this.status;
     }
 
+    @Override
     public HttpContext getContext() {
         return this.context;
     }
 
+    @Override
     public HttpRequest getHttpRequest() {
         return this.request;
     }
 
+    @Override
     public HttpResponse getHttpResponse() {
         return this.response;
     }
 
+    @Override
     public void requestInput() {
         this.session.setEvent(EventMask.READ);
     }
 
+    @Override
     public void requestOutput() {
         this.session.setEvent(EventMask.WRITE);
     }
 
+    @Override
     public void suspendInput() {
         this.session.clearEvent(EventMask.READ);
     }
 
+    @Override
     public void suspendOutput() {
         this.session.clearEvent(EventMask.WRITE);
     }
@@ -381,7 +428,7 @@ public class NHttpConnectionBase
             final SessionInputBuffer buffer,
             final HttpTransportMetricsImpl metrics) {
         if (len == ContentLengthStrategy.CHUNKED) {
-            return new ChunkDecoder(channel, buffer, metrics);
+            return new ChunkDecoder(channel, buffer, this.constraints, metrics);
         } else if (len == ContentLengthStrategy.IDENTITY) {
             return new IdentityDecoder(channel, buffer, metrics);
         } else {
@@ -432,10 +479,12 @@ public class NHttpConnectionBase
         }
     }
 
+    @Override
     public boolean hasBufferedInput() {
         return this.hasBufferedInput;
     }
 
+    @Override
     public boolean hasBufferedOutput() {
         return this.hasBufferedOutput;
     }
@@ -452,6 +501,7 @@ public class NHttpConnectionBase
         }
     }
 
+    @Override
     public void close() throws IOException {
         if (this.status != ACTIVE) {
             return;
@@ -465,14 +515,17 @@ public class NHttpConnectionBase
         }
     }
 
+    @Override
     public boolean isOpen() {
         return this.status == ACTIVE && !this.session.isClosed();
     }
 
+    @Override
     public boolean isStale() {
         return this.session.isClosed();
     }
 
+    @Override
     public InetAddress getLocalAddress() {
         final SocketAddress address = this.session.getLocalAddress();
         if (address instanceof InetSocketAddress) {
@@ -482,6 +535,7 @@ public class NHttpConnectionBase
         }
     }
 
+    @Override
     public int getLocalPort() {
         final SocketAddress address = this.session.getLocalAddress();
         if (address instanceof InetSocketAddress) {
@@ -491,6 +545,7 @@ public class NHttpConnectionBase
         }
     }
 
+    @Override
     public InetAddress getRemoteAddress() {
         final SocketAddress address = this.session.getRemoteAddress();
         if (address instanceof InetSocketAddress) {
@@ -500,6 +555,7 @@ public class NHttpConnectionBase
         }
     }
 
+    @Override
     public int getRemotePort() {
         final SocketAddress address = this.session.getRemoteAddress();
         if (address instanceof InetSocketAddress) {
@@ -509,49 +565,43 @@ public class NHttpConnectionBase
         }
     }
 
+    @Override
     public void setSocketTimeout(final int timeout) {
         this.session.setSocketTimeout(timeout);
     }
 
+    @Override
     public int getSocketTimeout() {
         return this.session.getSocketTimeout();
     }
 
+    @Override
     public void shutdown() throws IOException {
         this.status = CLOSED;
         this.session.shutdown();
     }
 
+    @Override
     public HttpConnectionMetrics getMetrics() {
         return this.connMetrics;
     }
 
     @Override
     public String toString() {
-        final StringBuilder buffer = new StringBuilder();
         final SocketAddress remoteAddress = this.session.getRemoteAddress();
         final SocketAddress localAddress = this.session.getLocalAddress();
         if (remoteAddress != null && localAddress != null) {
+            final StringBuilder buffer = new StringBuilder();
             NetUtils.formatAddress(buffer, localAddress);
             buffer.append("<->");
             NetUtils.formatAddress(buffer, remoteAddress);
+            return buffer.toString();
+        } else {
+            return "[Not bound]";
         }
-        buffer.append("[");
-        switch (this.status) {
-        case ACTIVE:
-            buffer.append("ACTIVE");
-            break;
-        case CLOSING:
-            buffer.append("CLOSING");
-            break;
-        case CLOSED:
-            buffer.append("CLOSED");
-            break;
-        }
-        buffer.append("]");
-        return buffer.toString();
     }
 
+    @Override
     public Socket getSocket() {
         if (this.session instanceof SocketAccessor) {
             return ((SocketAccessor) this.session).getSocket();
