@@ -59,7 +59,7 @@ public class ChunkEncoder extends AbstractContentEncoder {
      * @param metrics transport metrics.
      * @param fragementSizeHint fragment size hint defining an minimal size of a fragment
      *   that should be written out directly to the channel bypassing the session buffer.
-     *   Value <code>0</code> disables fragment buffering.
+     *   Value {@code 0} disables fragment buffering.
      */
     public ChunkEncoder(
             final WritableByteChannel channel,
@@ -83,6 +83,7 @@ public class ChunkEncoder extends AbstractContentEncoder {
         this(channel, buffer, metrics, 0);
     }
 
+    @Override
     public int write(final ByteBuffer src) throws IOException {
         if (src == null) {
             return 0;
