@@ -118,6 +118,7 @@ public abstract class AbstractMultiworkerIOReactor implements IOReactor {
     private final Thread[] threads;
     private final Object statusLock;
 
+    //TODO: make final
     protected IOReactorExceptionHandler exceptionHandler;
     protected List<ExceptionEvent> auditLog;
 
@@ -128,7 +129,7 @@ public abstract class AbstractMultiworkerIOReactor implements IOReactor {
      *
      * @param config I/O reactor configuration.
      * @param threadFactory the factory to create threads.
-     *   Can be <code>null</code>.
+     *   Can be {@code null}.
      * @throws IOReactorException in case if a non-recoverable I/O error.
      *
      * @since 4.2
@@ -152,6 +153,7 @@ public abstract class AbstractMultiworkerIOReactor implements IOReactor {
         } else {
             this.threadFactory = new DefaultThreadFactory();
         }
+        this.auditLog = new ArrayList<ExceptionEvent>();
         this.workerCount = this.config.getIoThreadCount();
         this.dispatchers = new BaseIOReactor[workerCount];
         this.workers = new Worker[workerCount];
@@ -193,7 +195,7 @@ public abstract class AbstractMultiworkerIOReactor implements IOReactor {
      *
      * @param workerCount number of worker I/O reactors.
      * @param threadFactory the factory to create threads.
-     *   Can be <code>null</code>.
+     *   Can be {@code null}.
      * @param params HTTP parameters.
      * @throws IOReactorException in case if a non-recoverable I/O error.
      *
@@ -207,6 +209,7 @@ public abstract class AbstractMultiworkerIOReactor implements IOReactor {
         this(convert(workerCount, params), threadFactory);
     }
 
+    @Override
     public IOReactorStatus getStatus() {
         return this.status;
     }
@@ -217,11 +220,9 @@ public abstract class AbstractMultiworkerIOReactor implements IOReactor {
      *
      * @return audit log.
      */
-    public synchronized List<ExceptionEvent> getAuditLog() {
-        if (this.auditLog != null) {
+    public List<ExceptionEvent> getAuditLog() {
+        synchronized (this.auditLog) {
             return new ArrayList<ExceptionEvent>(this.auditLog);
-        } else {
-            return null;
         }
     }
 
@@ -231,16 +232,15 @@ public abstract class AbstractMultiworkerIOReactor implements IOReactor {
      *
      * @param ex the exception thrown by the I/O reactor.
      * @param timestamp the time stamp of the exception. Can be
-     * <code>null</code> in which case the current date / time will be used.
+     * {@code null} in which case the current date / time will be used.
      */
     protected synchronized void addExceptionEvent(final Throwable ex, final Date timestamp) {
         if (ex == null) {
             return;
         }
-        if (this.auditLog == null) {
-            this.auditLog = new ArrayList<ExceptionEvent>();
+        synchronized (this.auditLog) {
+            this.auditLog.add(new ExceptionEvent(ex, timestamp != null ? timestamp : new Date()));
         }
-        this.auditLog.add(new ExceptionEvent(ex, timestamp != null ? timestamp : new Date()));
     }
 
     /**
@@ -302,6 +302,7 @@ public abstract class AbstractMultiworkerIOReactor implements IOReactor {
      * @throws InterruptedIOException if the dispatch thread is interrupted.
      * @throws IOReactorException in case if a non-recoverable I/O error.
      */
+    @Override
     public void execute(
             final IOEventDispatch eventDispatch) throws InterruptedIOException, IOReactorException {
         Args.notNull(eventDispatch, "Event dispatcher");
@@ -508,14 +509,14 @@ public abstract class AbstractMultiworkerIOReactor implements IOReactor {
         }
         final int linger = this.config.getSoLinger();
         if (linger >= 0) {
-            socket.setSoLinger(linger > 0, linger);
+            socket.setSoLinger(true, linger);
         }
     }
 
     /**
      * Blocks for the given period of time in milliseconds awaiting
      * the completion of the reactor shutdown. If the value of
-     * <code>timeout</code> is set to <code>0</code> this method blocks
+     * {@code timeout} is set to {@code 0} this method blocks
      * indefinitely.
      *
      * @param timeout the maximum wait time.
@@ -537,10 +538,12 @@ public abstract class AbstractMultiworkerIOReactor implements IOReactor {
         }
     }
 
+    @Override
     public void shutdown() throws IOException {
         shutdown(2000);
     }
 
+    @Override
     public void shutdown(final long waitMs) throws IOException {
         synchronized (this.statusLock) {
             if (this.status.compareTo(IOReactorStatus.ACTIVE) > 0) {
@@ -581,6 +584,7 @@ public abstract class AbstractMultiworkerIOReactor implements IOReactor {
             this.eventDispatch = eventDispatch;
         }
 
+        @Override
         public void run() {
             try {
                 this.dispatcher.execute(this.eventDispatch);
@@ -599,6 +603,7 @@ public abstract class AbstractMultiworkerIOReactor implements IOReactor {
 
         private final static AtomicLong COUNT = new AtomicLong(1);
 
+        @Override
         public Thread newThread(final Runnable r) {
             return new Thread(r, "I/O dispatcher " + COUNT.getAndIncrement());
         }
