@@ -70,7 +70,7 @@ public class DefaultConnectingIOReactor extends AbstractMultiworkerIOReactor
      *
      * @param config I/O reactor configuration.
      * @param threadFactory the factory to create threads.
-     *   Can be <code>null</code>.
+     *   Can be {@code null}.
      * @throws IOReactorException in case if a non-recoverable I/O error.
      *
      * @since 4.2
@@ -87,7 +87,7 @@ public class DefaultConnectingIOReactor extends AbstractMultiworkerIOReactor
      * Creates an instance of DefaultConnectingIOReactor with the given configuration.
      *
      * @param config I/O reactor configuration.
-     *   Can be <code>null</code>.
+     *   Can be {@code null}.
      * @throws IOReactorException in case if a non-recoverable I/O error.
      *
      * @since 4.2
@@ -217,6 +217,7 @@ public class DefaultConnectingIOReactor extends AbstractMultiworkerIOReactor
         }
     }
 
+    @Override
     public SessionRequest connect(
             final SocketAddress remoteAddress,
             final SocketAddress localAddress,
@@ -259,16 +260,17 @@ public class DefaultConnectingIOReactor extends AbstractMultiworkerIOReactor
                 throw new IOReactorException("Failure opening socket", ex);
             }
             try {
-                socketChannel.configureBlocking(false);
                 validateAddress(request.getLocalAddress());
                 validateAddress(request.getRemoteAddress());
 
+                socketChannel.configureBlocking(false);
+                prepareSocket(socketChannel.socket());
+
                 if (request.getLocalAddress() != null) {
                     final Socket sock = socketChannel.socket();
                     sock.setReuseAddress(this.config.isSoReuseAddress());
                     sock.bind(request.getLocalAddress());
                 }
-                prepareSocket(socketChannel.socket());
                 final boolean connected = socketChannel.connect(request.getRemoteAddress());
                 if (connected) {
                     final ChannelEntry entry = new ChannelEntry(socketChannel, request);
