@@ -73,7 +73,7 @@ public class DefaultListeningIOReactor extends AbstractMultiworkerIOReactor
      *
      * @param config I/O reactor configuration.
      * @param threadFactory the factory to create threads.
-     *   Can be <code>null</code>.
+     *   Can be {@code null}.
      * @throws IOReactorException in case if a non-recoverable I/O error.
      *
      * @since 4.2
@@ -91,7 +91,7 @@ public class DefaultListeningIOReactor extends AbstractMultiworkerIOReactor
      * Creates an instance of DefaultListeningIOReactor with the given configuration.
      *
      * @param config I/O reactor configuration.
-     *   Can be <code>null</code>.
+     *   Can be {@code null}.
      * @throws IOReactorException in case if a non-recoverable I/O error.
      *
      * @since 4.2
@@ -204,6 +204,7 @@ public class DefaultListeningIOReactor extends AbstractMultiworkerIOReactor
                 address,
                 new ListenerEndpointClosedCallback() {
 
+                    @Override
                     public void endpointClosed(final ListenerEndpoint endpoint) {
                         endpoints.remove(endpoint);
                     }
@@ -211,6 +212,7 @@ public class DefaultListeningIOReactor extends AbstractMultiworkerIOReactor
                 });
     }
 
+    @Override
     public ListenerEndpoint listen(final SocketAddress address) {
         Asserts.check(this.status.compareTo(IOReactorStatus.ACTIVE) <= 0,
                 "I/O reactor has been shut down");
@@ -240,7 +242,7 @@ public class DefaultListeningIOReactor extends AbstractMultiworkerIOReactor
                     socket.setReceiveBufferSize(this.config.getRcvBufSize());
                 }
                 serverChannel.configureBlocking(false);
-                socket.bind(address);
+                socket.bind(address, this.config.getBacklogSize());
             } catch (final IOException ex) {
                 closeChannel(serverChannel);
                 request.failed(ex);
@@ -266,6 +268,7 @@ public class DefaultListeningIOReactor extends AbstractMultiworkerIOReactor
         }
     }
 
+    @Override
     public Set<ListenerEndpoint> getEndpoints() {
         final Set<ListenerEndpoint> set = new HashSet<ListenerEndpoint>();
         synchronized (this.endpoints) {
@@ -282,6 +285,7 @@ public class DefaultListeningIOReactor extends AbstractMultiworkerIOReactor
         return set;
     }
 
+    @Override
     public void pause() throws IOException {
         if (this.paused) {
             return;
@@ -298,6 +302,7 @@ public class DefaultListeningIOReactor extends AbstractMultiworkerIOReactor
         }
     }
 
+    @Override
     public void resume() throws IOException {
         if (!this.paused) {
             return;
