@@ -29,24 +29,28 @@ package org.apache.http.impl.nio.reactor;
 
 import java.io.IOException;
 import java.net.InetSocketAddress;
+import java.net.Socket;
 import java.net.SocketAddress;
 import java.nio.channels.ByteChannel;
-import java.nio.channels.Channel;
 import java.nio.channels.SelectionKey;
 import java.nio.channels.SocketChannel;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
 
+import org.apache.http.annotation.ThreadSafe;
 import org.apache.http.nio.reactor.IOSession;
 import org.apache.http.nio.reactor.SessionBufferStatus;
+import org.apache.http.nio.reactor.SocketAccessor;
+import org.apache.http.util.Args;
 
 /**
  * Default implementation of {@link IOSession}.
  *
  * @since 4.0
  */
-public class IOSessionImpl implements IOSession {
+@ThreadSafe
+public class IOSessionImpl implements IOSession, SocketAccessor {
 
     private final SelectionKey key;
     private final ByteChannel channel;
@@ -61,9 +65,9 @@ public class IOSessionImpl implements IOSession {
 
     private final long startedTime;
 
-    private long lastReadTime;
-    private long lastWriteTime;
-    private long lastAccessTime;
+    private volatile long lastReadTime;
+    private volatile long lastWriteTime;
+    private volatile long lastAccessTime;
 
     /**
      * Creates new instance of IOSessionImpl.
@@ -79,9 +83,7 @@ public class IOSessionImpl implements IOSession {
             final InterestOpsCallback interestOpsCallback,
             final SessionClosedCallback sessionClosedCallback) {
         super();
-        if (key == null) {
-            throw new IllegalArgumentException("Selection key may not be null");
-        }
+        Args.notNull(key, "Selection key");
         this.key = key;
         this.channel = (ByteChannel) this.key.channel();
         this.interestOpsCallback = interestOpsCallback;
@@ -90,7 +92,7 @@ public class IOSessionImpl implements IOSession {
         this.currentEventMask = key.interestOps();
         this.socketTimeout = 0;
         this.status = ACTIVE;
-        long now = System.currentTimeMillis();
+        final long now = System.currentTimeMillis();
         this.startedTime = now;
         this.lastReadTime = now;
         this.lastWriteTime = now;
@@ -109,33 +111,36 @@ public class IOSessionImpl implements IOSession {
         this(key, null, sessionClosedCallback);
     }
 
+    @Override
     public ByteChannel channel() {
         return this.channel;
     }
 
+    @Override
     public SocketAddress getLocalAddress() {
-        Channel channel = this.channel;
-        if (channel instanceof SocketChannel) {
-            return ((SocketChannel)channel).socket().getLocalSocketAddress();
+        if (this.channel instanceof SocketChannel) {
+            return ((SocketChannel)this.channel).socket().getLocalSocketAddress();
         } else {
             return null;
         }
     }
 
+    @Override
     public SocketAddress getRemoteAddress() {
-        Channel channel = this.channel;
-        if (channel instanceof SocketChannel) {
-            return ((SocketChannel)channel).socket().getRemoteSocketAddress();
+        if (this.channel instanceof SocketChannel) {
+            return ((SocketChannel)this.channel).socket().getRemoteSocketAddress();
         } else {
             return null;
         }
     }
 
-    public synchronized int getEventMask() {
+    @Override
+    public int getEventMask() {
         return this.interestOpsCallback != null ? this.currentEventMask : this.key.interestOps();
     }
 
-    public synchronized void setEventMask(int ops) {
+    @Override
+    public synchronized void setEventMask(final int ops) {
         if (this.status == CLOSED) {
             return;
         }
@@ -144,7 +149,7 @@ public class IOSessionImpl implements IOSession {
             this.currentEventMask = ops;
 
             // local variable
-            InterestOpEntry entry = new InterestOpEntry(this.key, this.currentEventMask);
+            final InterestOpEntry entry = new InterestOpEntry(this.key, this.currentEventMask);
 
             // add this operation to the interestOps() queue
             this.interestOpsCallback.addInterestOps(entry);
@@ -154,7 +159,8 @@ public class IOSessionImpl implements IOSession {
         this.key.selector().wakeup();
     }
 
-    public synchronized void setEvent(int op) {
+    @Override
+    public synchronized void setEvent(final int op) {
         if (this.status == CLOSED) {
             return;
         }
@@ -163,18 +169,19 @@ public class IOSessionImpl implements IOSession {
             this.currentEventMask |= op;
 
             // local variable
-            InterestOpEntry entry = new InterestOpEntry(this.key, this.currentEventMask);
+            final InterestOpEntry entry = new InterestOpEntry(this.key, this.currentEventMask);
 
             // add this operation to the interestOps() queue
             this.interestOpsCallback.addInterestOps(entry);
         } else {
-            int ops = this.key.interestOps();
+            final int ops = this.key.interestOps();
             this.key.interestOps(ops | op);
         }
         this.key.selector().wakeup();
     }
 
-    public synchronized void clearEvent(int op) {
+    @Override
+    public synchronized void clearEvent(final int op) {
         if (this.status == CLOSED) {
             return;
         }
@@ -183,115 +190,131 @@ public class IOSessionImpl implements IOSession {
             this.currentEventMask &= ~op;
 
             // local variable
-            InterestOpEntry entry = new InterestOpEntry(this.key, this.currentEventMask);
+            final InterestOpEntry entry = new InterestOpEntry(this.key, this.currentEventMask);
 
             // add this operation to the interestOps() queue
             this.interestOpsCallback.addInterestOps(entry);
         } else {
-            int ops = this.key.interestOps();
+            final int ops = this.key.interestOps();
             this.key.interestOps(ops & ~op);
         }
         this.key.selector().wakeup();
     }
 
+    @Override
     public int getSocketTimeout() {
         return this.socketTimeout;
     }
 
-    public synchronized void setSocketTimeout(int timeout) {
+    @Override
+    public void setSocketTimeout(final int timeout) {
         this.socketTimeout = timeout;
         this.lastAccessTime = System.currentTimeMillis();
     }
 
-    public synchronized void close() {
-        if (this.status == CLOSED) {
-            return;
+    @Override
+    public void close() {
+        synchronized (this) {
+            if (this.status == CLOSED) {
+                return;
+            }
+            this.status = CLOSED;
         }
-        this.status = CLOSED;
-        this.key.cancel();
-        try {
-            this.key.channel().close();
-        } catch (IOException ex) {
-            // Munching exceptions is not nice
-            // but in this case it is justified
-        }
-        if (this.sessionClosedCallback != null) {
-            this.sessionClosedCallback.sessionClosed(this);
-        }
-        if (this.key.selector().isOpen()) {
-            this.key.selector().wakeup();
+        synchronized (this.key) {
+            this.key.cancel();
+            try {
+                this.key.channel().close();
+            } catch (final IOException ex) {
+                // Munching exceptions is not nice
+                // but in this case it is justified
+            }
+            if (this.sessionClosedCallback != null) {
+                this.sessionClosedCallback.sessionClosed(this);
+            }
+            if (this.key.selector().isOpen()) {
+                this.key.selector().wakeup();
+            }
         }
     }
 
+    @Override
     public int getStatus() {
         return this.status;
     }
 
+    @Override
     public boolean isClosed() {
         return this.status == CLOSED;
     }
 
+    @Override
     public void shutdown() {
         // For this type of session, a close() does exactly
         // what we need and nothing more.
         close();
     }
 
+    @Override
     public boolean hasBufferedInput() {
-        SessionBufferStatus bufferStatus = this.bufferStatus;
-        return bufferStatus != null && bufferStatus.hasBufferedInput();
+        final SessionBufferStatus buffStatus = this.bufferStatus;
+        return buffStatus != null && buffStatus.hasBufferedInput();
     }
 
+    @Override
     public boolean hasBufferedOutput() {
-        SessionBufferStatus bufferStatus = this.bufferStatus;
-        return bufferStatus != null && bufferStatus.hasBufferedOutput();
+        final SessionBufferStatus buffStatus = this.bufferStatus;
+        return buffStatus != null && buffStatus.hasBufferedOutput();
     }
 
+    @Override
     public void setBufferStatus(final SessionBufferStatus bufferStatus) {
         this.bufferStatus = bufferStatus;
     }
 
+    @Override
     public Object getAttribute(final String name) {
         return this.attributes.get(name);
     }
 
+    @Override
     public Object removeAttribute(final String name) {
         return this.attributes.remove(name);
     }
 
+    @Override
     public void setAttribute(final String name, final Object obj) {
         this.attributes.put(name, obj);
     }
 
-    public synchronized long getStartedTime() {
+    public long getStartedTime() {
         return this.startedTime;
     }
 
-    public synchronized long getLastReadTime() {
+    public long getLastReadTime() {
         return this.lastReadTime;
     }
 
-    public synchronized long getLastWriteTime() {
+    public long getLastWriteTime() {
         return this.lastWriteTime;
     }
 
-    public synchronized long getLastAccessTime() {
+    public long getLastAccessTime() {
         return this.lastAccessTime;
     }
 
-    synchronized void resetLastRead() {
-        long now = System.currentTimeMillis();
+    void resetLastRead() {
+        final long now = System.currentTimeMillis();
         this.lastReadTime = now;
         this.lastAccessTime = now;
     }
 
-    synchronized void resetLastWrite() {
-        long now = System.currentTimeMillis();
+    void resetLastWrite() {
+        final long now = System.currentTimeMillis();
         this.lastWriteTime = now;
         this.lastAccessTime = now;
     }
 
-    private static void formatOps(final StringBuilder buffer, int ops) {
+    private static void formatOps(final StringBuilder buffer, final int ops) {
         if ((ops & SelectionKey.OP_READ) > 0) {
             buffer.append('r');
         }
@@ -306,56 +329,60 @@ public class IOSessionImpl implements IOSession {
         }
     }
 
+    private static void formatAddress(final StringBuilder buffer, final SocketAddress socketAddress) {
+        if (socketAddress instanceof InetSocketAddress) {
+            final InetSocketAddress addr = ((InetSocketAddress) socketAddress);
+            buffer.append(addr.getAddress() != null ? addr.getAddress().getHostAddress() :
+                addr.getAddress())
+            .append(':')
+            .append(addr.getPort());
+        } else {
+            buffer.append(socketAddress);
+        }
+    }
+
     @Override
-    public synchronized String toString() {
-        StringBuilder buffer = new StringBuilder();
-
-        final SocketAddress remoteAddress = getRemoteAddress();
-        final SocketAddress localAddress = getLocalAddress();
-
-        if (remoteAddress != null && localAddress != null) {
-            if (remoteAddress instanceof InetSocketAddress &&
-                localAddress instanceof InetSocketAddress) {
-
-                final InetSocketAddress remote = ((InetSocketAddress) remoteAddress);
-                final InetSocketAddress local  = ((InetSocketAddress) localAddress);
-
-                buffer.append(local.getAddress() != null ? local.getAddress().getHostAddress() : local.getAddress())
-                .append(':')
-                .append(local.getPort())
-                .append("<->")
-                .append(remote.getAddress() != null ? remote.getAddress().getHostAddress() : remote.getAddress())
-                .append(':')
-                .append(remote.getPort());
-
-            } else {
-                buffer.append(localAddress)
-                .append("<->")
-                .append(remoteAddress);
+    public String toString() {
+        final StringBuilder buffer = new StringBuilder();
+        synchronized (this.key) {
+            final SocketAddress remoteAddress = getRemoteAddress();
+            final SocketAddress localAddress = getLocalAddress();
+            if (remoteAddress != null && localAddress != null) {
+                formatAddress(buffer, localAddress);
+                buffer.append("<->");
+                formatAddress(buffer, remoteAddress);
+            }
+            buffer.append('[');
+            switch (this.status) {
+            case ACTIVE:
+                buffer.append("ACTIVE");
+                break;
+            case CLOSING:
+                buffer.append("CLOSING");
+                break;
+            case CLOSED:
+                buffer.append("CLOSED");
+                break;
+            }
+            buffer.append("][");
+            if (this.key.isValid()) {
+                formatOps(buffer, this.interestOpsCallback != null ?
+                        this.currentEventMask : this.key.interestOps());
+                buffer.append(':');
+                formatOps(buffer, this.key.readyOps());
             }
         }
+        buffer.append(']');
+        return new String(buffer);
+    }
 
-        buffer.append("[");
-        switch (this.status) {
-        case ACTIVE:
-            buffer.append("ACTIVE");
-            break;
-        case CLOSING:
-            buffer.append("CLOSING");
-            break;
-        case CLOSED:
-            buffer.append("CLOSED");
-            break;
+    @Override
+    public Socket getSocket() {
+        if (this.channel instanceof SocketChannel) {
+            return ((SocketChannel) this.channel).socket();
+        } else {
+            return null;
         }
-        buffer.append("][");
-        if (this.key.isValid()) {
-            formatOps(buffer, this.interestOpsCallback != null ?
-                    this.currentEventMask : this.key.interestOps());
-            buffer.append(":");
-            formatOps(buffer, this.key.readyOps());
-        }
-        buffer.append("]");
-        return buffer.toString();
     }
 
 }
