@@ -27,14 +27,17 @@
 
 package org.apache.http.impl.nio.reactor;
 
-import org.apache.http.nio.reactor.SessionRequest;
+import org.apache.http.annotation.Immutable;
+import org.apache.http.util.Args;
 
 /**
  * Session request handle class used by I/O reactor implementations to keep
- * a reference to a {@link SessionRequest} along with the time the request
- * was made.
+ * a reference to a {@link org.apache.http.nio.reactor.SessionRequest} along
+ * with the time the request was made.
+ *
  * @since 4.0
  */
+@Immutable
 public class SessionRequestHandle {
 
     private final SessionRequestImpl sessionRequest;
@@ -42,9 +45,7 @@ public class SessionRequestHandle {
 
     public SessionRequestHandle(final SessionRequestImpl sessionRequest) {
         super();
-        if (sessionRequest == null) {
-            throw new IllegalArgumentException("Session request may not be null");
-        }
+        Args.notNull(sessionRequest, "Session request");
         this.sessionRequest = sessionRequest;
         this.requestTime = System.currentTimeMillis();
     }
