@@ -29,8 +29,10 @@ package org.apache.http.nio.entity;
 
 import org.apache.http.Header;
 import org.apache.http.HttpEntity;
+import org.apache.http.annotation.NotThreadSafe;
 import org.apache.http.entity.BasicHttpEntity;
 import org.apache.http.nio.util.ContentInputBuffer;
+import org.apache.http.util.Args;
 
 /**
  * HTTP entity wrapper whose content is provided by a
@@ -38,9 +40,10 @@ import org.apache.http.nio.util.ContentInputBuffer;
  *
  * @since 4.0
  */
+@NotThreadSafe
 public class ContentBufferEntity extends BasicHttpEntity {
 
-    private HttpEntity wrappedEntity;
+    private final HttpEntity wrappedEntity;
 
     /**
      * Creates new instance of ContentBufferEntity.
@@ -50,9 +53,7 @@ public class ContentBufferEntity extends BasicHttpEntity {
      */
     public ContentBufferEntity(final HttpEntity entity, final ContentInputBuffer buffer) {
         super();
-        if (entity == null) {
-            throw new IllegalArgumentException("HTTP entity may not be null");
-        }
+        Args.notNull(entity, "HTTP entity");
         this.wrappedEntity = entity;
         setContent(new ContentInputStream(buffer));
     }
