@@ -108,10 +108,12 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
         this.connFactory = connFactory;
         this.addressResolver = new SocketAddressResolver<T>() {
 
+            @Override
             public SocketAddress resolveLocalAddress(final T route) throws IOException {
                 return AbstractNIOConnPool.this.resolveLocalAddress(route);
             }
 
+            @Override
             public SocketAddress resolveRemoteAddress(final T route) throws IOException {
                 return AbstractNIOConnPool.this.resolveRemoteAddress(route);
             }
@@ -193,6 +195,12 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
     protected void onRelease(final E entry) {
     }
 
+    /**
+     * @since 4.4
+     */
+    protected void onReuse(final E entry) {
+    }
+
     public boolean isShutdown() {
         return this.isShutDown.get();
     }
@@ -278,6 +286,7 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
         return future;
     }
 
+    @Override
     public Future<E> lease(final T route, final Object state, final FutureCallback<E> callback) {
         return lease(route, state, -1, TimeUnit.MICROSECONDS, callback);
     }
@@ -286,6 +295,7 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
         return lease(route, state, -1, TimeUnit.MICROSECONDS, null);
     }
 
+    @Override
     public void release(final E entry, final boolean reusable) {
         if (entry == null) {
             return;
@@ -373,6 +383,7 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
             this.available.remove(entry);
             this.leased.add(entry);
             request.completed(entry);
+            onReuse(entry);
             onLease(entry);
             return true;
         }
@@ -563,6 +574,7 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public void setMaxTotal(final int max) {
         Args.positive(max, "Max value");
         this.lock.lock();
@@ -573,6 +585,7 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public int getMaxTotal() {
         this.lock.lock();
         try {
@@ -582,6 +595,7 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public void setDefaultMaxPerRoute(final int max) {
         Args.positive(max, "Max value");
         this.lock.lock();
@@ -592,6 +606,7 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public int getDefaultMaxPerRoute() {
         this.lock.lock();
         try {
@@ -601,6 +616,7 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public void setMaxPerRoute(final T route, final int max) {
         Args.notNull(route, "Route");
         Args.positive(max, "Max value");
@@ -612,6 +628,7 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public int getMaxPerRoute(final T route) {
         Args.notNull(route, "Route");
         this.lock.lock();
@@ -622,6 +639,7 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public PoolStats getTotalStats() {
         this.lock.lock();
         try {
@@ -635,6 +653,7 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public PoolStats getStats(final T route) {
         Args.notNull(route, "Route");
         this.lock.lock();
@@ -650,6 +669,20 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    /**
+     * Returns snapshot of all knows routes
+     *
+     * @since 4.4
+     */
+    public Set<T> getRoutes() {
+        this.lock.lock();
+        try {
+            return new HashSet<T>(routeToPool.keySet());
+        } finally {
+            this.lock.unlock();
+        }
+    }
+
     /**
      * Enumerates all available connections.
      *
@@ -729,6 +762,7 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
         final long deadline = System.currentTimeMillis() - time;
         enumAvailable(new PoolEntryCallback<T, C>() {
 
+            @Override
             public void process(final PoolEntry<T, C> entry) {
                 if (entry.getUpdated() <= deadline) {
                     entry.close();
@@ -742,6 +776,7 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
         final long now = System.currentTimeMillis();
         enumAvailable(new PoolEntryCallback<T, C>() {
 
+            @Override
             public void process(final PoolEntry<T, C> entry) {
                 if (entry.isExpired(now)) {
                     entry.close();
@@ -766,18 +801,22 @@ public abstract class AbstractNIOConnPool<T, C, E extends PoolEntry<T, C>>
 
     class InternalSessionRequestCallback implements SessionRequestCallback {
 
+        @Override
         public void completed(final SessionRequest request) {
             requestCompleted(request);
         }
 
+        @Override
         public void cancelled(final SessionRequest request) {
             requestCancelled(request);
         }
 
+        @Override
         public void failed(final SessionRequest request) {
             requestFailed(request);
         }
 
+        @Override
         public void timeout(final SessionRequest request) {
             requestTimeout(request);
         }
