@@ -73,7 +73,7 @@ public abstract class AbstractAsyncResponseConsumer<T> implements HttpAsyncRespo
      * Invoked to process a chunk of content from the {@link ContentDecoder}.
      * The {@link IOControl} interface can be used to suspend input events
      * if the consumer is temporarily unable to consume more content.
-     * <p/>
+     * <p>
      * The consumer can use the {@link ContentDecoder#isCompleted()} method
      * to find out whether or not the message content has been fully consumed.
      *
@@ -121,6 +121,7 @@ public abstract class AbstractAsyncResponseConsumer<T> implements HttpAsyncRespo
     /**
      * Use {@link #onResponseReceived(HttpResponse)} instead.
      */
+    @Override
     public final void responseReceived(
             final HttpResponse response) throws IOException, HttpException {
         onResponseReceived(response);
@@ -134,6 +135,7 @@ public abstract class AbstractAsyncResponseConsumer<T> implements HttpAsyncRespo
     /**
      * Use {@link #onContentReceived(ContentDecoder, IOControl)} instead.
      */
+    @Override
     public final void consumeContent(
             final ContentDecoder decoder, final IOControl ioctrl) throws IOException {
         onContentReceived(decoder, ioctrl);
@@ -142,6 +144,7 @@ public abstract class AbstractAsyncResponseConsumer<T> implements HttpAsyncRespo
     /**
      * Use {@link #buildResult(HttpContext)} instead.
      */
+    @Override
     public final void responseCompleted(final HttpContext context) {
         if (this.completed.compareAndSet(false, true)) {
             try {
@@ -154,6 +157,7 @@ public abstract class AbstractAsyncResponseConsumer<T> implements HttpAsyncRespo
         }
     }
 
+    @Override
     public final boolean cancel() {
         if (this.completed.compareAndSet(false, true)) {
             releaseResources();
@@ -162,6 +166,7 @@ public abstract class AbstractAsyncResponseConsumer<T> implements HttpAsyncRespo
         return false;
     }
 
+    @Override
     public final void failed(final Exception ex) {
         if (this.completed.compareAndSet(false, true)) {
             this.ex = ex;
@@ -169,6 +174,7 @@ public abstract class AbstractAsyncResponseConsumer<T> implements HttpAsyncRespo
         }
     }
 
+    @Override
     public final void close() throws IOException {
         if (this.completed.compareAndSet(false, true)) {
             releaseResources();
@@ -176,14 +182,17 @@ public abstract class AbstractAsyncResponseConsumer<T> implements HttpAsyncRespo
         }
     }
 
+    @Override
     public Exception getException() {
         return this.ex;
     }
 
+    @Override
     public T getResult() {
         return this.result;
     }
 
+    @Override
     public boolean isDone() {
         return this.completed.get();
     }
