@@ -29,6 +29,8 @@ package org.apache.http.nio.protocol;
 
 import java.io.IOException;
 import java.net.SocketTimeoutException;
+import java.util.Queue;
+import java.util.concurrent.ConcurrentLinkedQueue;
 
 import org.apache.http.ConnectionClosedException;
 import org.apache.http.ExceptionLogger;
@@ -164,17 +166,24 @@ public class HttpAsyncRequestExecutor implements NHttpClientEventHandler {
                         state.getRequestState() == MessageState.COMPLETED,
                 "Unexpected request state %s", state.getRequestState());
 
-        if (state.getRequestState() != MessageState.READY) {
+        if (state.getRequestState() == MessageState.COMPLETED) {
+            conn.suspendOutput();
             return;
         }
-        final HttpAsyncClientExchangeHandler handler = getHandler(conn);
-        if (handler == null || handler.isDone()) {
-            return;
+        final HttpContext context = conn.getContext();
+        final HttpAsyncClientExchangeHandler handler;
+        synchronized (context) {
+            handler = getHandler(conn);
+            if (handler == null || handler.isDone()) {
+                conn.suspendOutput();
+                return;
+            }
         }
         final boolean pipelined = handler.getClass().getAnnotation(Pipelined.class) != null;
 
         final HttpRequest request = handler.generateRequest();
         if (request == null) {
+            conn.suspendOutput();
             return;
         }
         final ProtocolVersion version = request.getRequestLine().getProtocolVersion();
@@ -182,7 +191,9 @@ public class HttpAsyncRequestExecutor implements NHttpClientEventHandler {
             throw new ProtocolException(version + " cannot be used with request pipelining");
         }
         state.setRequest(request);
-
+        if (pipelined) {
+            state.getRequestQueue().add(request);
+        }
         if (request instanceof HttpEntityEnclosingRequest) {
             final boolean expectContinue = ((HttpEntityEnclosingRequest) request).expectContinue();
             if (expectContinue && pipelined) {
@@ -242,12 +253,21 @@ public class HttpAsyncRequestExecutor implements NHttpClientEventHandler {
         Asserts.check(state.getResponseState() == MessageState.READY,
                 "Unexpected request state %s", state.getResponseState());
 
-        final HttpRequest request = state.getRequest();
-        if (request == null) {
-            throw new HttpException("Out of sequence response");
-        }
         final HttpAsyncClientExchangeHandler handler = getHandler(conn);
         Asserts.notNull(handler, "Client exchange handler");
+
+        final boolean pipelined = handler.getClass().getAnnotation(Pipelined.class) != null;
+        final HttpRequest request;
+        if (pipelined) {
+            request = state.getRequestQueue().poll();
+            Asserts.notNull(request, "HTTP request");
+        } else {
+            request = state.getRequest();
+            if (request == null) {
+                throw new HttpException("Out of sequence response");
+            }
+        }
+
         final HttpResponse response = conn.getHttpResponse();
 
         final int statusCode = response.getStatusLine().getStatusCode();
@@ -444,6 +464,7 @@ public class HttpAsyncRequestExecutor implements NHttpClientEventHandler {
 
     static class State {
 
+        private final Queue<HttpRequest> requestQueue;
         private volatile MessageState requestState;
         private volatile MessageState responseState;
         private volatile HttpRequest request;
@@ -453,6 +474,7 @@ public class HttpAsyncRequestExecutor implements NHttpClientEventHandler {
 
         State() {
             super();
+            this.requestQueue = new ConcurrentLinkedQueue<HttpRequest>();
             this.valid = true;
             this.requestState = MessageState.READY;
             this.responseState = MessageState.READY;
@@ -490,6 +512,10 @@ public class HttpAsyncRequestExecutor implements NHttpClientEventHandler {
             this.response = response;
         }
 
+        public Queue<HttpRequest> getRequestQueue() {
+            return this.requestQueue;
+        }
+
         public int getTimeout() {
             return this.timeout;
         }
