@@ -144,22 +144,28 @@ public class HttpAsyncRequester {
         final BasicAsyncClientExchangeHandler<T> handler = new BasicAsyncClientExchangeHandler<T>(
                 requestProducer, responseConsumer, callback, context, conn,
                 this.httpprocessor, this.connReuseStrategy);
-        initExection(handler, conn);
+        initExecution(handler, conn);
         return handler.getFuture();
     }
 
-    private void initExection(
+    private void initExecution(
             final HttpAsyncClientExchangeHandler handler, final NHttpClientConnection conn) {
-        conn.getContext().setAttribute(HttpAsyncRequestExecutor.HTTP_HANDLER, handler);
-        if (!conn.isOpen()) {
-            handler.failed(new ConnectionClosedException("Connection closed"));
+
+        final HttpContext context = conn.getContext();
+        synchronized (context) {
+            context.setAttribute(HttpAsyncRequestExecutor.HTTP_HANDLER, handler);
+            if (!conn.isOpen()) {
+                handler.failed(new ConnectionClosedException("Connection closed"));
+            } else {
+                conn.requestOutput();
+            }
+        }
+        if (handler.isDone()) {
             try {
                 handler.close();
             } catch (final IOException ex) {
                 log(ex);
             }
-        } else {
-            conn.requestOutput();
         }
     }
 
@@ -295,7 +301,7 @@ public class HttpAsyncRequester {
                 new RequestExecutionCallback<T, E>(future, poolEntry, connPool),
                 context, conn,
                 this.httpprocessor, this.connReuseStrategy);
-        initExection(handler, conn);
+        initExecution(handler, conn);
         return future;
     }
 
@@ -335,7 +341,7 @@ public class HttpAsyncRequester {
                 new RequestExecutionCallback<List<T>, E>(future, poolEntry, connPool),
                 context, conn,
                 this.httpprocessor, this.connReuseStrategy);
-        initExection(handler, conn);
+        initExecution(handler, conn);
         return future;
     }
 
@@ -408,7 +414,7 @@ public class HttpAsyncRequester {
                     this.requestProducer, this.responseConsumer,
                     new RequestExecutionCallback<T, E>(this.requestFuture, result, this.connPool),
                     this.context, conn, httpprocessor, connReuseStrategy);
-            initExection(handler, conn);
+            initExecution(handler, conn);
         }
 
         @Override
@@ -477,7 +483,7 @@ public class HttpAsyncRequester {
                     this.requestProducers, this.responseConsumers,
                     new RequestExecutionCallback<List<T>, E>(this.requestFuture, result, this.connPool),
                     this.context, conn, httpprocessor, connReuseStrategy);
-            initExection(handler, conn);
+            initExecution(handler, conn);
         }
 
         @Override
