@@ -138,6 +138,7 @@ public class TestDefaultNHttpServerConnection {
             this.response = response;
         }
 
+        @Override
         public Void answer(final InvocationOnMock invocation) throws Throwable {
             final Object[] args = invocation.getArguments();
             final NHttpServerConnection conn = (NHttpServerConnection) args[0];
@@ -155,6 +156,7 @@ public class TestDefaultNHttpServerConnection {
             this.contentProducer = contentProducer;
         }
 
+        @Override
         public Void answer(final InvocationOnMock invocation) throws Throwable {
             final Object[] args = invocation.getArguments();
             final IOControl ioctrl = (IOControl) args[0];
@@ -186,7 +188,6 @@ public class TestDefaultNHttpServerConnection {
         Assert.assertNull(conn.contentEncoder);
         Assert.assertEquals("HTTP/1.1 200 OK\r\n\r\nstuff", wchannel.dump(Consts.ASCII));
 
-        Mockito.verify(session, Mockito.times(1)).clearEvent(SelectionKey.OP_WRITE);
         Mockito.verify(wchannel, Mockito.times(1)).write(Matchers.<ByteBuffer>any());
     }
 
@@ -212,7 +213,6 @@ public class TestDefaultNHttpServerConnection {
         Assert.assertNull(conn.contentEncoder);
         Assert.assertEquals("HTTP/1.1 200 OK\r\n\r\na lot of various stuff", wchannel.dump(Consts.ASCII));
 
-        Mockito.verify(session, Mockito.times(1)).clearEvent(SelectionKey.OP_WRITE);
         Mockito.verify(wchannel, Mockito.times(2)).write(Matchers.<ByteBuffer>any());
     }
 
@@ -238,7 +238,6 @@ public class TestDefaultNHttpServerConnection {
         Assert.assertNull(conn.contentEncoder);
         Assert.assertEquals("HTTP/1.1 200 OK\r\n\r\nstuff", wchannel.dump(Consts.ASCII));
 
-        Mockito.verify(session, Mockito.times(1)).clearEvent(SelectionKey.OP_WRITE);
         Mockito.verify(wchannel, Mockito.times(1)).write(Matchers.<ByteBuffer>any());
     }
 
@@ -264,7 +263,6 @@ public class TestDefaultNHttpServerConnection {
         Assert.assertNull(conn.contentEncoder);
         Assert.assertEquals("HTTP/1.1 200 OK\r\n\r\na lot of various stuff", wchannel.dump(Consts.ASCII));
 
-        Mockito.verify(session, Mockito.times(1)).clearEvent(SelectionKey.OP_WRITE);
         Mockito.verify(wchannel, Mockito.times(2)).write(Matchers.<ByteBuffer>any());
     }
 
@@ -349,7 +347,6 @@ public class TestDefaultNHttpServerConnection {
         Assert.assertEquals("HTTP/1.1 200 OK\r\nTransfer-Encoding: chunked\r\n\r\n" +
                 "5\r\na lot\r\n11\r\n of various stuff\r\n0\r\n\r\n", wchannel.dump(Consts.ASCII));
 
-        Mockito.verify(session, Mockito.times(1)).clearEvent(SelectionKey.OP_WRITE);
         Mockito.verify(wchannel, Mockito.times(2)).write(Matchers.<ByteBuffer>any());
     }
 
@@ -420,6 +417,7 @@ public class TestDefaultNHttpServerConnection {
             this.requests = requests;
         }
 
+        @Override
         public Void answer(final InvocationOnMock invocation) throws Throwable {
             final Object[] args = invocation.getArguments();
             final NHttpServerConnection conn = (NHttpServerConnection) args[0];
@@ -443,6 +441,7 @@ public class TestDefaultNHttpServerConnection {
             this.buf = buf;
         }
 
+        @Override
         public Void answer(final InvocationOnMock invocation) throws Throwable {
             final Object[] args = invocation.getArguments();
             final ContentDecoder decoder = (ContentDecoder) args[1];
