@@ -31,10 +31,14 @@ import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.nio.channels.ReadableByteChannel;
 
+import org.apache.http.ConnectionClosedException;
 import org.apache.http.Consts;
 import org.apache.http.Header;
 import org.apache.http.MalformedChunkCodingException;
+import org.apache.http.MessageConstraintException;
 import org.apache.http.ReadableByteChannelMock;
+import org.apache.http.TruncatedChunkException;
+import org.apache.http.config.MessageConstraints;
 import org.apache.http.impl.io.HttpTransportMetricsImpl;
 import org.apache.http.impl.nio.reactor.SessionInputBufferImpl;
 import org.apache.http.nio.reactor.SessionInputBuffer;
@@ -211,7 +215,7 @@ public class TestChunkDecoder {
         Assert.assertTrue(decoder.isCompleted());
     }
 
-    @Test
+    @Test(expected=MalformedChunkCodingException.class)
     public void testMalformedChunkSizeDecoding() throws Exception {
         final String s = "5\r\n01234\r\n5zz\r\n56789\r\n6\r\nabcdef\r\n0\r\n\r\n";
         final ReadableByteChannel channel = new ReadableByteChannelMock(
@@ -222,16 +226,10 @@ public class TestChunkDecoder {
         final ChunkDecoder decoder = new ChunkDecoder(channel, inbuf, metrics);
 
         final ByteBuffer dst = ByteBuffer.allocate(1024);
-
-        try {
-            decoder.read(dst);
-            Assert.fail("MalformedChunkCodingException should have been thrown");
-        } catch (final MalformedChunkCodingException ex) {
-            // expected
-        }
+        decoder.read(dst);
     }
 
-    @Test
+    @Test(expected=MalformedChunkCodingException.class)
     public void testMalformedChunkEndingDecoding() throws Exception {
         final String s = "5\r\n01234\r\n5\r\n56789\r\r6\r\nabcdef\r\n0\r\n\r\n";
         final ReadableByteChannel channel = new ReadableByteChannelMock(
@@ -242,16 +240,10 @@ public class TestChunkDecoder {
         final ChunkDecoder decoder = new ChunkDecoder(channel, inbuf, metrics);
 
         final ByteBuffer dst = ByteBuffer.allocate(1024);
-
-        try {
-            decoder.read(dst);
-            Assert.fail("MalformedChunkCodingException should have been thrown");
-        } catch (final MalformedChunkCodingException ex) {
-            // expected
-        }
+        decoder.read(dst);
     }
 
-    @Test
+    @Test(expected=TruncatedChunkException.class)
     public void testMalformedChunkTruncatedChunk() throws Exception {
         final String s = "3\r\n12";
         final ReadableByteChannel channel = new ReadableByteChannelMock(
@@ -263,12 +255,7 @@ public class TestChunkDecoder {
 
         final ByteBuffer dst = ByteBuffer.allocate(1024);
         Assert.assertEquals(2, decoder.read(dst));
-        try {
-            decoder.read(dst);
-            Assert.fail("MalformedChunkCodingException should have been thrown");
-        } catch (final MalformedChunkCodingException ex) {
-            // expected
-        }
+        decoder.read(dst);
     }
 
     @Test
@@ -294,7 +281,7 @@ public class TestChunkDecoder {
         Assert.assertEquals("abcde  fghij", footers[0].getValue());
     }
 
-    @Test
+    @Test(expected=IOException.class)
     public void testMalformedFooters() throws Exception {
         final String s = "10;key=\"value\"\r\n1234567890123456\r\n" +
                 "5\r\n12345\r\n5\r\n12345\r\n0\r\nFooter1 abcde\r\n\r\n";
@@ -306,17 +293,11 @@ public class TestChunkDecoder {
         final ChunkDecoder decoder = new ChunkDecoder(channel, inbuf, metrics);
 
         final ByteBuffer dst = ByteBuffer.allocate(1024);
-
-        try {
-            decoder.read(dst);
-            Assert.fail("MalformedChunkCodingException should have been thrown");
-        } catch (final IOException ex) {
-            // expected
-        }
+        decoder.read(dst);
     }
 
-    @Test
-    public void testEndOfStreamConditionReadingLastChunk() throws Exception {
+    @Test(expected=MalformedChunkCodingException.class)
+    public void testMissingLastCRLF() throws Exception {
         final String s = "10\r\n1234567890123456\r\n" +
                 "5\r\n12345\r\n5\r\n12345";
         final ReadableByteChannel channel = new ReadableByteChannelMock(
@@ -328,17 +309,38 @@ public class TestChunkDecoder {
 
         final ByteBuffer dst = ByteBuffer.allocate(1024);
 
-        int bytesRead = 0;
         while (dst.hasRemaining() && !decoder.isCompleted()) {
-            final int i = decoder.read(dst);
-            if (i > 0) {
-                bytesRead += i;
-            }
+            decoder.read(dst);
         }
+    }
 
-        Assert.assertEquals(26, bytesRead);
-        Assert.assertEquals("12345678901234561234512345", CodecTestUtils.convert(dst));
-        Assert.assertTrue(decoder.isCompleted());
+    @Test(expected=ConnectionClosedException.class)
+    public void testMissingClosingChunk() throws Exception {
+        final String s = "10\r\n1234567890123456\r\n" +
+                "5\r\n12345\r\n5\r\n12345\r\n";
+        final ReadableByteChannel channel = new ReadableByteChannelMock(
+                new String[] {s}, Consts.ASCII);
+
+        final SessionInputBuffer inbuf = new SessionInputBufferImpl(1024, 256, Consts.ASCII);
+        final HttpTransportMetricsImpl metrics = new HttpTransportMetricsImpl();
+        final ChunkDecoder decoder = new ChunkDecoder(channel, inbuf, metrics);
+
+        final ByteBuffer dst = ByteBuffer.allocate(1024);
+
+        long bytesRead = 0;
+        try {
+            while (dst.hasRemaining() && !decoder.isCompleted()) {
+                final int i = decoder.read(dst);
+                if (i > 0) {
+                    bytesRead += i;
+                }
+            }
+        } catch (final MalformedChunkCodingException ex) {
+            Assert.assertEquals(26L, bytesRead);
+            Assert.assertEquals("12345678901234561234512345", CodecTestUtils.convert(dst));
+            Assert.assertTrue(decoder.isCompleted());
+            throw ex;
+        }
     }
 
     @Test
@@ -400,6 +402,151 @@ public class TestChunkDecoder {
         Assert.assertTrue(decoder.isCompleted());
     }
 
+    @Test
+    public void testTooLongChunkHeader() throws Exception {
+        final String s = "5; and some very looooong comment\r\n12345\r\n0\r\n";
+        final ReadableByteChannel channel1 = new ReadableByteChannelMock(
+                new String[] {s}, Consts.ASCII);
+
+        final SessionInputBuffer inbuf1 = new SessionInputBufferImpl(1024, 256,
+                MessageConstraints.DEFAULT, null, null);
+        final HttpTransportMetricsImpl metrics1 = new HttpTransportMetricsImpl();
+        final ChunkDecoder decoder1 = new ChunkDecoder(channel1, inbuf1, metrics1);
+
+        final ByteBuffer dst = ByteBuffer.allocate(1024);
+
+        while (dst.hasRemaining() && !decoder1.isCompleted()) {
+            decoder1.read(dst);
+        }
+        Assert.assertEquals("12345", CodecTestUtils.convert(dst));
+        Assert.assertTrue(decoder1.isCompleted());
+
+        final ReadableByteChannel channel2 = new ReadableByteChannelMock(
+                new String[] {s}, Consts.ASCII);
+
+        final SessionInputBuffer inbuf2 = new SessionInputBufferImpl(1024, 256,
+                MessageConstraints.lineLen(10), null, null);
+        final HttpTransportMetricsImpl metrics2 = new HttpTransportMetricsImpl();
+        final ChunkDecoder decoder2 = new ChunkDecoder(channel2, inbuf2, metrics2);
+
+        dst.clear();
+        try {
+            decoder2.read(dst);
+            Assert.fail("MessageConstraintException expected");
+        } catch (MessageConstraintException ex) {
+        }
+    }
+
+    @Test
+    public void testTooLongFooter() throws Exception {
+        final String s = "10\r\n1234567890123456\r\n" +
+                "0\r\nFooter1: looooooooooooooooooooooooooooooooooooooooooooooooooooooog\r\n\r\n";
+//        final String s = "10\r\n1234567890123456\r\n" +
+//                "0\r\nFooter1: looooooooooooooooooooooooooooooooooooooooog\r\n   \r\n  fghij\r\n\r\n";
+        final ReadableByteChannel channel1 = new ReadableByteChannelMock(
+                new String[] {s}, Consts.ASCII);
+        final SessionInputBuffer inbuf1 = new SessionInputBufferImpl(1024, 256,
+                MessageConstraints.DEFAULT, Consts.ASCII);
+        final HttpTransportMetricsImpl metrics1 = new HttpTransportMetricsImpl();
+        final ChunkDecoder decoder1 = new ChunkDecoder(channel1, inbuf1, metrics1);
+
+        final ByteBuffer dst = ByteBuffer.allocate(1024);
+
+        final int bytesRead = decoder1.read(dst);
+        Assert.assertEquals(16, bytesRead);
+        Assert.assertEquals("1234567890123456", CodecTestUtils.convert(dst));
+        final Header[] footers = decoder1.getFooters();
+        Assert.assertNotNull(footers);
+        Assert.assertEquals(1, footers.length);
+
+        final ReadableByteChannel channel2 = new ReadableByteChannelMock(
+                new String[] {s}, Consts.ASCII);
+        final SessionInputBuffer inbuf2 = new SessionInputBufferImpl(1024, 256,
+                MessageConstraints.lineLen(25), Consts.ASCII);
+        final HttpTransportMetricsImpl metrics2 = new HttpTransportMetricsImpl();
+        final ChunkDecoder decoder2 = new ChunkDecoder(channel2, inbuf2, metrics2);
+
+        dst.clear();
+        try {
+            decoder2.read(dst);
+            Assert.fail("MessageConstraintException expected");
+        } catch (MessageConstraintException ex) {
+        }
+    }
+
+    @Test
+    public void testTooLongFoldedFooter() throws Exception {
+        final String s = "10\r\n1234567890123456\r\n" +
+                "0\r\nFooter1: blah\r\n  blah\r\n  blah\r\n  blah\r\n  blah\r\n  blah\r\n  blah\r\n  blah\r\n\r\n";
+        final ReadableByteChannel channel1 = new ReadableByteChannelMock(
+                new String[] {s}, Consts.ASCII);
+        final SessionInputBuffer inbuf1 = new SessionInputBufferImpl(1024, 256,
+                MessageConstraints.DEFAULT, Consts.ASCII);
+        final HttpTransportMetricsImpl metrics1 = new HttpTransportMetricsImpl();
+        final ChunkDecoder decoder1 = new ChunkDecoder(channel1, inbuf1, metrics1);
+
+        final ByteBuffer dst = ByteBuffer.allocate(1024);
+
+        final int bytesRead = decoder1.read(dst);
+        Assert.assertEquals(16, bytesRead);
+        Assert.assertEquals("1234567890123456", CodecTestUtils.convert(dst));
+        final Header[] footers = decoder1.getFooters();
+        Assert.assertNotNull(footers);
+        Assert.assertEquals(1, footers.length);
+
+        final MessageConstraints constraints = MessageConstraints.lineLen(25);
+        final ReadableByteChannel channel2 = new ReadableByteChannelMock(
+                new String[] {s}, Consts.ASCII);
+        final SessionInputBuffer inbuf2 = new SessionInputBufferImpl(1024, 256,
+                constraints, Consts.ASCII);
+        final HttpTransportMetricsImpl metrics2 = new HttpTransportMetricsImpl();
+        final ChunkDecoder decoder2 = new ChunkDecoder(channel2, inbuf2, constraints, metrics2);
+
+        dst.clear();
+        try {
+            decoder2.read(dst);
+            Assert.fail("MessageConstraintException expected");
+        } catch (MessageConstraintException ex) {
+        }
+    }
+
+    @Test
+    public void testTooManyFooters() throws Exception {
+        final String s = "10\r\n1234567890123456\r\n" +
+                "0\r\nFooter1: blah\r\nFooter2: blah\r\nFooter3: blah\r\nFooter4: blah\r\n\r\n";
+        final ReadableByteChannel channel1 = new ReadableByteChannelMock(
+                new String[] {s}, Consts.ASCII);
+        final SessionInputBuffer inbuf1 = new SessionInputBufferImpl(1024, 256,
+                MessageConstraints.DEFAULT, Consts.ASCII);
+        final HttpTransportMetricsImpl metrics1 = new HttpTransportMetricsImpl();
+        final ChunkDecoder decoder1 = new ChunkDecoder(channel1, inbuf1, metrics1);
+
+        final ByteBuffer dst = ByteBuffer.allocate(1024);
+
+        final int bytesRead = decoder1.read(dst);
+        Assert.assertEquals(16, bytesRead);
+        Assert.assertEquals("1234567890123456", CodecTestUtils.convert(dst));
+        final Header[] footers = decoder1.getFooters();
+        Assert.assertNotNull(footers);
+        Assert.assertEquals(4, footers.length);
+
+        final MessageConstraints constraints = MessageConstraints.custom()
+                .setMaxHeaderCount(3).build();
+        final ReadableByteChannel channel2 = new ReadableByteChannelMock(
+                new String[] {s}, Consts.ASCII);
+        final SessionInputBuffer inbuf2 = new SessionInputBufferImpl(1024, 256,
+                constraints, Consts.ASCII);
+        final HttpTransportMetricsImpl metrics2 = new HttpTransportMetricsImpl();
+        final ChunkDecoder decoder2 = new ChunkDecoder(channel2, inbuf2, constraints, metrics2);
+
+        dst.clear();
+        try {
+            decoder2.read(dst);
+            Assert.fail("MessageConstraintException expected");
+        } catch (MessageConstraintException ex) {
+        }
+    }
+
     @Test
     public void testInvalidConstructor() {
         final ReadableByteChannel channel = new ReadableByteChannelMock(
@@ -426,7 +573,7 @@ public class TestChunkDecoder {
         }
     }
 
-    @Test
+    @Test(expected=IllegalArgumentException.class)
     public void testInvalidInput() throws Exception {
         final String s = "10;key=\"value\"\r\n1234567890123456\r\n" +
                 "5\r\n12345\r\n5\r\n12345\r\n0\r\nFooter1 abcde\r\n\r\n";
@@ -436,13 +583,7 @@ public class TestChunkDecoder {
         final SessionInputBuffer inbuf = new SessionInputBufferImpl(1024, 256, Consts.ASCII);
         final HttpTransportMetricsImpl metrics = new HttpTransportMetricsImpl();
         final ChunkDecoder decoder = new ChunkDecoder(channel, inbuf, metrics);
-
-        try {
-            decoder.read(null);
-            Assert.fail("IllegalArgumentException should have been thrown");
-        } catch (final IllegalArgumentException ex) {
-            // expected
-        }
+        decoder.read(null);
     }
 
 }
