@@ -182,8 +182,8 @@ public class TestLengthDelimitedEncoder {
         createTempFile();
         RandomAccessFile testfile = new RandomAccessFile(this.tmpfile, "rw");
         try {
-            testfile.write("stuff;".getBytes("US-ASCII"));
-            testfile.write("more stuff; and a lot more stuff".getBytes("US-ASCII"));
+            testfile.write("stuff;".getBytes(Consts.ASCII));
+            testfile.write("more stuff; and a lot more stuff".getBytes(Consts.ASCII));
         } finally {
             testfile.close();
         }
@@ -245,7 +245,7 @@ public class TestLengthDelimitedEncoder {
         createTempFile();
         RandomAccessFile testfile = new RandomAccessFile(this.tmpfile, "rw");
         try {
-            testfile.write("more stuff".getBytes("US-ASCII"));
+            testfile.write("more stuff".getBytes(Consts.ASCII));
         } finally {
             testfile.close();
         }
@@ -274,8 +274,8 @@ public class TestLengthDelimitedEncoder {
         createTempFile();
         RandomAccessFile testfile = new RandomAccessFile(this.tmpfile, "rw");
         try {
-            testfile.write("stuff;".getBytes("US-ASCII"));
-            testfile.write("more stuff".getBytes("US-ASCII"));
+            testfile.write("stuff;".getBytes(Consts.ASCII));
+            testfile.write("more stuff".getBytes(Consts.ASCII));
         } finally {
             testfile.close();
         }
@@ -307,8 +307,8 @@ public class TestLengthDelimitedEncoder {
         createTempFile();
         RandomAccessFile testfile = new RandomAccessFile(this.tmpfile, "rw");
         try {
-            testfile.write("stuff;".getBytes("US-ASCII"));
-            testfile.write("more stuff".getBytes("US-ASCII"));
+            testfile.write("stuff;".getBytes(Consts.ASCII));
+            testfile.write("more stuff".getBytes(Consts.ASCII));
         } finally {
             testfile.close();
         }
@@ -340,7 +340,7 @@ public class TestLengthDelimitedEncoder {
         createTempFile();
         RandomAccessFile testfile = new RandomAccessFile(this.tmpfile, "rw");
         try {
-            testfile.write("stuff".getBytes("US-ASCII"));
+            testfile.write("stuff".getBytes(Consts.ASCII));
         } finally {
             testfile.close();
         }
