@@ -29,14 +29,16 @@ package org.apache.http.nio.pool;
 import java.io.IOException;
 import java.net.InetSocketAddress;
 import java.net.SocketAddress;
-import java.net.SocketTimeoutException;
+import java.net.ConnectException;
 import java.net.UnknownHostException;
+import java.util.Collections;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.http.concurrent.BasicFuture;
 import org.apache.http.nio.reactor.ConnectingIOReactor;
+import org.apache.http.nio.reactor.IOReactorStatus;
 import org.apache.http.nio.reactor.IOSession;
 import org.apache.http.nio.reactor.SessionRequest;
 import org.apache.http.nio.reactor.SessionRequestCallback;
@@ -74,6 +76,7 @@ public class TestNIOConnPool {
 
     static class LocalConnFactory implements NIOConnFactory<String, IOSession> {
 
+        @Override
         public IOSession create(final String route, final IOSession session) throws IOException {
             return session;
         }
@@ -82,10 +85,12 @@ public class TestNIOConnPool {
 
     static class LocalAddressResolver implements SocketAddressResolver<String> {
 
+        @Override
         public SocketAddress resolveLocalAddress(final String route) {
             return null;
         }
 
+        @Override
         public SocketAddress resolveRemoteAddress(final String route) {
             return InetSocketAddress.createUnresolved(route, 80);
         }
@@ -122,6 +127,7 @@ public class TestNIOConnPool {
         Assert.assertEquals(0, totals.getLeased());
         Assert.assertEquals(0, totals.getPending());
         Assert.assertEquals(10, totals.getMax());
+        Assert.assertEquals(Collections.emptySet(), pool.getRoutes());
         final PoolStats stats = pool.getStats("somehost");
         Assert.assertEquals(0, stats.getAvailable());
         Assert.assertEquals(0, stats.getLeased());
@@ -240,6 +246,7 @@ public class TestNIOConnPool {
                 Mockito.any(SocketAddress.class),
                 Mockito.any(), Mockito.any(SessionRequestCallback.class))).
                 thenReturn(sessionRequest);
+        Mockito.when(ioreactor.getStatus()).thenReturn(IOReactorStatus.ACTIVE);
         final LocalSessionPool pool = new LocalSessionPool(ioreactor, 2, 10);
         final Future<LocalPoolEntry> future = pool.lease("somehost", null);
 
@@ -289,7 +296,7 @@ public class TestNIOConnPool {
             future.get();
             Assert.fail("ExecutionException should have been thrown");
         } catch (final ExecutionException ex) {
-            Assert.assertTrue(ex.getCause() instanceof SocketTimeoutException);
+            Assert.assertTrue(ex.getCause() instanceof ConnectException);
         }
 
         totals = pool.getTotalStats();
@@ -786,6 +793,7 @@ public class TestNIOConnPool {
         Assert.assertEquals(0, totals.getAvailable());
         Assert.assertEquals(0, totals.getLeased());
         Assert.assertEquals(1, totals.getPending());
+        Assert.assertEquals(Collections.singleton("somehost"), pool.getRoutes());
         final PoolStats stats = pool.getStats("somehost");
         Assert.assertEquals(0, stats.getAvailable());
         Assert.assertEquals(0, stats.getLeased());
