@@ -75,18 +75,22 @@ public class FileEntity extends AbstractHttpEntity implements Cloneable {
         this.file = Args.notNull(file, "File");
     }
 
+    @Override
     public boolean isRepeatable() {
         return true;
     }
 
+    @Override
     public long getContentLength() {
         return this.file.length();
     }
 
+    @Override
     public InputStream getContent() throws IOException {
         return new FileInputStream(this.file);
     }
 
+    @Override
     public void writeTo(final OutputStream outstream) throws IOException {
         Args.notNull(outstream, "Output stream");
         final InputStream instream = new FileInputStream(this.file);
@@ -105,8 +109,9 @@ public class FileEntity extends AbstractHttpEntity implements Cloneable {
     /**
      * Tells that this entity is not streaming.
      *
-     * @return <code>false</code>
+     * @return {@code false}
      */
+    @Override
     public boolean isStreaming() {
         return false;
     }
