@@ -40,7 +40,7 @@ import org.apache.http.util.Args;
 /**
  * The strict implementation of the content length strategy. This class
  * will throw {@link ProtocolException} if it encounters an unsupported
- * transfer encoding or a malformed <code>Content-Length</code> header
+ * transfer encoding or a malformed {@code Content-Length} header
  * value.
  * <p>
  * This class recognizes "chunked" and "identitiy" transfer-coding only.
@@ -55,7 +55,7 @@ public class StrictContentLengthStrategy implements ContentLengthStrategy {
     private final int implicitLen;
 
     /**
-     * Creates <tt>StrictContentLengthStrategy</tt> instance with the given length used per default
+     * Creates {@code StrictContentLengthStrategy} instance with the given length used per default
      * when content length is not explicitly specified in the message.
      *
      * @param implicitLen implicit content length.
@@ -68,13 +68,14 @@ public class StrictContentLengthStrategy implements ContentLengthStrategy {
     }
 
     /**
-     * Creates <tt>StrictContentLengthStrategy</tt> instance. {@link ContentLengthStrategy#IDENTITY}
+     * Creates {@code StrictContentLengthStrategy} instance. {@link ContentLengthStrategy#IDENTITY}
      * is used per default when content length is not explicitly specified in the message.
      */
     public StrictContentLengthStrategy() {
         this(IDENTITY);
     }
 
+    @Override
     public long determineLength(final HttpMessage message) throws HttpException {
         Args.notNull(message, "HTTP message");
         // Although Transfer-Encoding is specified as a list, in practice
