@@ -62,10 +62,10 @@ public class BasicHttpResponse extends AbstractHttpMessage implements HttpRespon
      *
      * @param statusline        the status line
      * @param catalog           the reason phrase catalog, or
-     *                          <code>null</code> to disable automatic
+     *                          {@code null} to disable automatic
      *                          reason phrase lookup
      * @param locale            the locale for looking up reason phrases, or
-     *                          <code>null</code> for the system locale
+     *                          {@code null} for the system locale
      */
     public BasicHttpResponse(final StatusLine statusline,
                              final ReasonPhraseCatalog catalog,
@@ -104,7 +104,7 @@ public class BasicHttpResponse extends AbstractHttpMessage implements HttpRespon
      * @param ver       the protocol version of the response
      * @param code      the status code of the response
      * @param reason    the reason phrase to the status code, or
-     *                  <code>null</code>
+     *                  {@code null}
      */
     public BasicHttpResponse(final ProtocolVersion ver,
                              final int code,
@@ -121,11 +121,13 @@ public class BasicHttpResponse extends AbstractHttpMessage implements HttpRespon
 
 
     // non-javadoc, see interface HttpMessage
+    @Override
     public ProtocolVersion getProtocolVersion() {
         return this.ver;
     }
 
     // non-javadoc, see interface HttpResponse
+    @Override
     public StatusLine getStatusLine() {
         if (this.statusline == null) {
             this.statusline = new BasicStatusLine(
@@ -137,15 +139,18 @@ public class BasicHttpResponse extends AbstractHttpMessage implements HttpRespon
     }
 
     // non-javadoc, see interface HttpResponse
+    @Override
     public HttpEntity getEntity() {
         return this.entity;
     }
 
+    @Override
     public Locale getLocale() {
         return this.locale;
     }
 
     // non-javadoc, see interface HttpResponse
+    @Override
     public void setStatusLine(final StatusLine statusline) {
         this.statusline = Args.notNull(statusline, "Status line");
         this.ver = statusline.getProtocolVersion();
@@ -154,6 +159,7 @@ public class BasicHttpResponse extends AbstractHttpMessage implements HttpRespon
     }
 
     // non-javadoc, see interface HttpResponse
+    @Override
     public void setStatusLine(final ProtocolVersion ver, final int code) {
         Args.notNegative(code, "Status code");
         this.statusline = null;
@@ -163,6 +169,7 @@ public class BasicHttpResponse extends AbstractHttpMessage implements HttpRespon
     }
 
     // non-javadoc, see interface HttpResponse
+    @Override
     public void setStatusLine(
             final ProtocolVersion ver, final int code, final String reason) {
         Args.notNegative(code, "Status code");
@@ -173,6 +180,7 @@ public class BasicHttpResponse extends AbstractHttpMessage implements HttpRespon
     }
 
     // non-javadoc, see interface HttpResponse
+    @Override
     public void setStatusCode(final int code) {
         Args.notNegative(code, "Status code");
         this.statusline = null;
@@ -181,18 +189,21 @@ public class BasicHttpResponse extends AbstractHttpMessage implements HttpRespon
     }
 
     // non-javadoc, see interface HttpResponse
+    @Override
     public void setReasonPhrase(final String reason) {
         this.statusline = null;
         this.reasonPhrase = reason;
     }
 
     // non-javadoc, see interface HttpResponse
+    @Override
     public void setEntity(final HttpEntity entity) {
         this.entity = entity;
     }
 
+    @Override
     public void setLocale(final Locale locale) {
-        this.locale =  Args.notNull(locale, "Locale");
+        this.locale = Args.notNull(locale, "Locale");
         this.statusline = null;
     }
 
@@ -203,7 +214,7 @@ public class BasicHttpResponse extends AbstractHttpMessage implements HttpRespon
      *
      * @param code      the status code for which to look up the reason
      *
-     * @return  the reason phrase, or <code>null</code> if there is none
+     * @return  the reason phrase, or {@code null} if there is none
      */
     protected String getReason(final int code) {
         return this.reasonCatalog != null ? this.reasonCatalog.getReason(code,
@@ -212,7 +223,15 @@ public class BasicHttpResponse extends AbstractHttpMessage implements HttpRespon
 
     @Override
     public String toString() {
-        return getStatusLine() + " " + this.headergroup;
+        final StringBuilder sb = new StringBuilder();
+        sb.append(getStatusLine());
+        sb.append(' ');
+        sb.append(this.headergroup);
+        if (this.entity != null) {
+            sb.append(' ');
+            sb.append(this.entity);
+        }
+        return sb.toString();
     }
 
 }
