@@ -47,7 +47,7 @@ import org.apache.http.util.Asserts;
 
 /**
  * Abstract synchronous (blocking) pool of connections.
- * <p/>
+ * <p>
  * Please note that this class does not maintain its own pool of execution {@link Thread}s.
  * Therefore, one <b>must</b> call {@link Future#get()} or {@link Future#get(long, TimeUnit)}
  * method on the {@link Future} object returned by the
@@ -75,6 +75,7 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
     private volatile boolean isShutDown;
     private volatile int defaultMaxPerRoute;
     private volatile int maxTotal;
+    private volatile int validateAfterInactivity;
 
     public AbstractConnPool(
             final ConnFactory<T, C> connFactory,
@@ -82,8 +83,8 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
             final int maxTotal) {
         super();
         this.connFactory = Args.notNull(connFactory, "Connection factory");
-        this.defaultMaxPerRoute = Args.notNegative(defaultMaxPerRoute, "Max per route value");
-        this.maxTotal = Args.notNegative(maxTotal, "Max total value");
+        this.defaultMaxPerRoute = Args.positive(defaultMaxPerRoute, "Max per route value");
+        this.maxTotal = Args.positive(maxTotal, "Max total value");
         this.lock = new ReentrantLock();
         this.routeToPool = new HashMap<T, RouteSpecificPool<T, C, E>>();
         this.leased = new HashSet<E>();
@@ -109,6 +110,19 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
     protected void onRelease(final E entry) {
     }
 
+    /**
+     * @since 4.4
+     */
+    protected void onReuse(final E entry) {
+    }
+
+    /**
+     * @since 4.4
+     */
+    protected boolean validate(final E entry) {
+        return true;
+    }
+
     public boolean isShutdown() {
         return this.isShutDown;
     }
@@ -158,12 +172,13 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
 
     /**
      * {@inheritDoc}
-     * <p/>
+     * <p>
      * Please note that this class does not maintain its own pool of execution
      * {@link Thread}s. Therefore, one <b>must</b> call {@link Future#get()}
      * or {@link Future#get(long, TimeUnit)} method on the {@link Future}
      * returned by this method in order for the lease operation to complete.
      */
+    @Override
     public Future<E> lease(final T route, final Object state, final FutureCallback<E> callback) {
         Args.notNull(route, "Route");
         Asserts.check(!this.isShutDown, "Connection pool shut down");
@@ -185,7 +200,7 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
     /**
      * Attempts to lease a connection for the given route and with the given
      * state from the pool.
-     * <p/>
+     * <p>
      * Please note that this class does not maintain its own pool of execution
      * {@link Thread}s. Therefore, one <b>must</b> call {@link Future#get()}
      * or {@link Future#get(long, TimeUnit)} method on the {@link Future}
@@ -195,7 +210,7 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
      * @param state arbitrary object that represents a particular state
      *  (usually a security principal or a unique token identifying
      *  the user whose credentials have been used while establishing the connection).
-     *  May be <code>null</code>.
+     *  May be {@code null}.
      * @return future for a leased pool entry.
      */
     public Future<E> lease(final T route, final Object state) {
@@ -225,8 +240,16 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
                     if (entry == null) {
                         break;
                     }
-                    if (entry.isClosed() || entry.isExpired(System.currentTimeMillis())) {
+                    if (entry.isExpired(System.currentTimeMillis())) {
                         entry.close();
+                    } else if (this.validateAfterInactivity > 0) {
+                        if (entry.getUpdated() + this.validateAfterInactivity <= System.currentTimeMillis()) {
+                            if (!validate(entry)) {
+                                entry.close();
+                            }
+                        }
+                    }
+                    if (entry.isClosed()) {
                         this.available.remove(entry);
                         pool.free(entry, false);
                     } else {
@@ -236,6 +259,7 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
                 if (entry != null) {
                     this.available.remove(entry);
                     this.leased.add(entry);
+                    onReuse(entry);
                     return entry;
                 }
 
@@ -300,18 +324,7 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
-    private void notifyPending(final RouteSpecificPool<T, C, E> pool) {
-        PoolEntryFuture<E> future = pool.nextPending();
-        if (future != null) {
-            this.pending.remove(future);
-        } else {
-            future = this.pending.poll();
-        }
-        if (future != null) {
-            future.wakeup();
-        }
-    }
-
+    @Override
     public void release(final E entry, final boolean reusable) {
         this.lock.lock();
         try {
@@ -324,7 +337,15 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
                 } else {
                     entry.close();
                 }
-                notifyPending(pool);
+                PoolEntryFuture<E> future = pool.nextPending();
+                if (future != null) {
+                    this.pending.remove(future);
+                } else {
+                    future = this.pending.poll();
+                }
+                if (future != null) {
+                    future.wakeup();
+                }
             }
         } finally {
             this.lock.unlock();
@@ -340,8 +361,9 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public void setMaxTotal(final int max) {
-        Args.notNegative(max, "Max value");
+        Args.positive(max, "Max value");
         this.lock.lock();
         try {
             this.maxTotal = max;
@@ -350,6 +372,7 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public int getMaxTotal() {
         this.lock.lock();
         try {
@@ -359,8 +382,9 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public void setDefaultMaxPerRoute(final int max) {
-        Args.notNegative(max, "Max per route value");
+        Args.positive(max, "Max per route value");
         this.lock.lock();
         try {
             this.defaultMaxPerRoute = max;
@@ -369,6 +393,7 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public int getDefaultMaxPerRoute() {
         this.lock.lock();
         try {
@@ -378,9 +403,10 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public void setMaxPerRoute(final T route, final int max) {
         Args.notNull(route, "Route");
-        Args.notNegative(max, "Max per route value");
+        Args.positive(max, "Max per route value");
         this.lock.lock();
         try {
             this.maxPerRoute.put(route, Integer.valueOf(max));
@@ -389,6 +415,7 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public int getMaxPerRoute(final T route) {
         Args.notNull(route, "Route");
         this.lock.lock();
@@ -399,6 +426,7 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public PoolStats getTotalStats() {
         this.lock.lock();
         try {
@@ -412,6 +440,7 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    @Override
     public PoolStats getStats(final T route) {
         Args.notNull(route, "Route");
         this.lock.lock();
@@ -427,6 +456,21 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
         }
     }
 
+    /**
+     * Returns snapshot of all knows routes
+     * @return the set of routes
+     *
+     * @since 4.4
+     */
+    public Set<T> getRoutes() {
+        this.lock.lock();
+        try {
+            return new HashSet<T>(routeToPool.keySet());
+        } finally {
+            this.lock.unlock();
+        }
+    }
+
     /**
      * Enumerates all available connections.
      *
@@ -435,7 +479,17 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
     protected void enumAvailable(final PoolEntryCallback<T, C> callback) {
         this.lock.lock();
         try {
-            enumEntries(this.available.iterator(), callback);
+            final Iterator<E> it = this.available.iterator();
+            while (it.hasNext()) {
+                final E entry = it.next();
+                callback.process(entry);
+                if (entry.isClosed()) {
+                    final RouteSpecificPool<T, C, E> pool = getPool(entry.getRoute());
+                    pool.remove(entry);
+                    it.remove();
+                }
+            }
+            purgePoolMap();
         } finally {
             this.lock.unlock();
         }
@@ -449,19 +503,22 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
     protected void enumLeased(final PoolEntryCallback<T, C> callback) {
         this.lock.lock();
         try {
-            enumEntries(this.leased.iterator(), callback);
+            final Iterator<E> it = this.leased.iterator();
+            while (it.hasNext()) {
+                final E entry = it.next();
+                callback.process(entry);
+            }
         } finally {
             this.lock.unlock();
         }
     }
 
-    private void enumEntries(final Iterator<E> it, final PoolEntryCallback<T, C> callback) {
+    private void purgePoolMap() {
+        final Iterator<Map.Entry<T, RouteSpecificPool<T, C, E>>> it = this.routeToPool.entrySet().iterator();
         while (it.hasNext()) {
-            final E entry = it.next();
-            callback.process(entry);
-            if (entry.isClosed()) {
-                final RouteSpecificPool<T, C, E> pool = getPool(entry.getRoute());
-                pool.remove(entry);
+            final Map.Entry<T, RouteSpecificPool<T, C, E>> entry = it.next();
+            final RouteSpecificPool<T, C, E> pool = entry.getValue();
+            if (pool.getPendingCount() + pool.getAllocatedCount() == 0) {
                 it.remove();
             }
         }
@@ -483,6 +540,7 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
         final long deadline = System.currentTimeMillis() - time;
         enumAvailable(new PoolEntryCallback<T, C>() {
 
+            @Override
             public void process(final PoolEntry<T, C> entry) {
                 if (entry.getUpdated() <= deadline) {
                     entry.close();
@@ -499,6 +557,7 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
         final long now = System.currentTimeMillis();
         enumAvailable(new PoolEntryCallback<T, C>() {
 
+            @Override
             public void process(final PoolEntry<T, C> entry) {
                 if (entry.isExpired(now)) {
                     entry.close();
@@ -508,6 +567,22 @@ public abstract class AbstractConnPool<T, C, E extends PoolEntry<T, C>>
         });
     }
 
+    /**
+     * @return the number of milliseconds
+     * @since 4.4
+     */
+    public int getValidateAfterInactivity() {
+        return this.validateAfterInactivity;
+    }
+
+    /**
+     * @param ms the number of milliseconds
+     * @since 4.4
+     */
+    public void setValidateAfterInactivity(final int ms) {
+        this.validateAfterInactivity = ms;
+    }
+
     @Override
     public String toString() {
         final StringBuilder buffer = new StringBuilder();
