@@ -52,20 +52,20 @@ import org.apache.http.util.EncodingUtils;
 import org.apache.http.util.EntityUtils;
 
 /**
- * <tt>HttpService</tt> is a server side HTTP protocol handler based on
+ * {@code HttpService} is a server side HTTP protocol handler based on
  * the classic (blocking) I/O model.
- * <p/>
- * <tt>HttpService</tt> relies on {@link HttpProcessor} to generate mandatory
+ * <p>
+ * {@code HttpService} relies on {@link HttpProcessor} to generate mandatory
  * protocol headers for all outgoing messages and apply common, cross-cutting
  * message transformations to all incoming and outgoing messages, whereas
  * individual {@link HttpRequestHandler}s are expected to implement
  * application specific content generation and processing.
- * <p/>
- * <tt>HttpService</tt> uses {@link HttpRequestHandlerMapper} to map
+ * <p>
+ * {@code HttpService} uses {@link HttpRequestHandlerMapper} to map
  * matching request handler for a particular request URI of an incoming HTTP
  * request.
- * <p/>
- * <tt>HttpService</tt> can use optional {@link HttpExpectationVerifier}
+ * <p>
+ * {@code HttpService} can use optional {@link HttpExpectationVerifier}
  * to ensure that incoming requests meet server's expectations.
  *
  * @since 4.0
@@ -167,9 +167,9 @@ public class HttpService {
      * Create a new HTTP service.
      *
      * @param processor the processor to use on requests and responses
-     * @param connStrategy the connection reuse strategy. If <code>null</code>
+     * @param connStrategy the connection reuse strategy. If {@code null}
      *   {@link DefaultConnectionReuseStrategy#INSTANCE} will be used.
-     * @param responseFactory  the response factory. If <code>null</code>
+     * @param responseFactory  the response factory. If {@code null}
      *   {@link DefaultHttpResponseFactory#INSTANCE} will be used.
      * @param handlerMapper  the handler mapper. May be null.
      * @param expectationVerifier the expectation verifier. May be null.
@@ -196,9 +196,9 @@ public class HttpService {
      * Create a new HTTP service.
      *
      * @param processor the processor to use on requests and responses
-     * @param connStrategy the connection reuse strategy. If <code>null</code>
+     * @param connStrategy the connection reuse strategy. If {@code null}
      *   {@link DefaultConnectionReuseStrategy#INSTANCE} will be used.
-     * @param responseFactory  the response factory. If <code>null</code>
+     * @param responseFactory  the response factory. If {@code null}
      *   {@link DefaultHttpResponseFactory#INSTANCE} will be used.
      * @param handlerMapper  the handler mapper. May be null.
      *
@@ -300,11 +300,11 @@ public class HttpService {
 
         context.setAttribute(HttpCoreContext.HTTP_CONNECTION, conn);
 
+        HttpRequest request = null;
         HttpResponse response = null;
 
         try {
-
-            final HttpRequest request = conn.receiveRequestHeader();
+            request = conn.receiveRequestHeader();
             if (request instanceof HttpEntityEnclosingRequest) {
 
                 if (((HttpEntityEnclosingRequest) request).expectContinue()) {
@@ -358,7 +358,9 @@ public class HttpService {
 
         this.processor.process(response, context);
         conn.sendResponseHeader(response);
-        conn.sendResponseEntity(response);
+        if (canResponseHaveBody(request, response)) {
+            conn.sendResponseEntity(response);
+        }
         conn.flush();
 
         if (!this.connStrategy.keepAlive(response, context)) {
@@ -366,6 +368,17 @@ public class HttpService {
         }
     }
 
+    private boolean canResponseHaveBody(final HttpRequest request, final HttpResponse response) {
+        if (request != null && "HEAD".equalsIgnoreCase(request.getRequestLine().getMethod())) {
+            return false;
+        }
+        final int status = response.getStatusLine().getStatusCode();
+        return status >= HttpStatus.SC_OK
+                && status != HttpStatus.SC_NO_CONTENT
+                && status != HttpStatus.SC_NOT_MODIFIED
+                && status != HttpStatus.SC_RESET_CONTENT;
+    }
+
     /**
      * Handles the given exception and generates an HTTP response to be sent
      * back to the client to inform about the exceptional condition encountered
@@ -438,6 +451,7 @@ public class HttpService {
             this.resolver = resolver;
         }
 
+        @Override
         public HttpRequestHandler lookup(final HttpRequest request) {
             return resolver.lookup(request.getRequestLine().getUri());
         }
