@@ -37,7 +37,7 @@ import org.apache.http.annotation.ThreadSafe;
 import org.apache.http.util.Args;
 
 /**
- * RequestDate interceptor is responsible for adding <code>Date</code> header
+ * RequestDate interceptor is responsible for adding {@code Date} header
  * to the outgoing requests This interceptor is optional for client side
  * protocol processors.
  *
@@ -52,6 +52,7 @@ public class RequestDate implements HttpRequestInterceptor {
         super();
     }
 
+    @Override
     public void process(final HttpRequest request, final HttpContext context)
             throws HttpException, IOException {
         Args.notNull(request, "HTTP request");
