@@ -42,7 +42,7 @@ import org.apache.http.util.Args;
 
 /**
  * RequestExpectContinue is responsible for enabling the 'expect-continue'
- * handshake by adding <code>Expect</code> header. This interceptor is
+ * handshake by adding {@code Expect} header. This interceptor is
  * recommended for client side protocol processors.
  *
  * @since 4.0
@@ -69,6 +69,7 @@ public class RequestExpectContinue implements HttpRequestInterceptor {
         this.activeByDefault = activeByDefault;
     }
 
+    @Override
     public void process(final HttpRequest request, final HttpContext context)
             throws HttpException, IOException {
         Args.notNull(request, "HTTP request");
