@@ -29,83 +29,85 @@ package org.apache.http.entity;
 
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
+import java.io.InputStream;
 import java.io.OutputStream;
 
-import junit.framework.TestCase;
-
 import org.apache.http.HttpEntity;
+import org.apache.http.util.EntityUtils;
+import org.junit.Assert;
+import org.junit.Test;
 
 /**
  * Unit tests for {@link EntityTemplate}.
- *
  */
-public class TestEntityTemplate extends TestCase {
-
-    public TestEntityTemplate(String testName) {
-        super(testName);
-    }
+public class TestEntityTemplate {
 
+    @Test
     public void testBasics() throws Exception {
 
-        HttpEntity httpentity = new EntityTemplate(new ContentProducer() {
+        final HttpEntity httpentity = new EntityTemplate(new ContentProducer() {
 
+            @Override
             public void writeTo(final OutputStream outstream) throws IOException {
                 outstream.write('a');
             }
 
         });
 
-        assertEquals(-1, httpentity.getContentLength());
-        assertTrue(httpentity.isRepeatable());
-        assertFalse(httpentity.isStreaming());
+        Assert.assertEquals(-1, httpentity.getContentLength());
+        Assert.assertTrue(httpentity.isRepeatable());
+        Assert.assertFalse(httpentity.isStreaming());
     }
 
+    @Test
     public void testIllegalConstructor() throws Exception {
         try {
             new EntityTemplate(null);
-            fail("IllegalArgumentException should have been thrown");
-        } catch (IllegalArgumentException ex) {
+            Assert.fail("IllegalArgumentException should have been thrown");
+        } catch (final IllegalArgumentException ex) {
             // expected
         }
     }
 
+    @Test
     public void testWriteTo() throws Exception {
-        HttpEntity httpentity = new EntityTemplate(new ContentProducer() {
+        final HttpEntity httpentity = new EntityTemplate(new ContentProducer() {
 
+            @Override
             public void writeTo(final OutputStream outstream) throws IOException {
                 outstream.write('a');
             }
 
         });
 
-        ByteArrayOutputStream out = new ByteArrayOutputStream();
+        final ByteArrayOutputStream out = new ByteArrayOutputStream();
         httpentity.writeTo(out);
-        byte[] bytes2 = out.toByteArray();
-        assertNotNull(bytes2);
-        assertEquals(1, bytes2.length);
+        final byte[] bytes2 = out.toByteArray();
+        Assert.assertNotNull(bytes2);
+        Assert.assertEquals(1, bytes2.length);
 
         try {
             httpentity.writeTo(null);
-            fail("IllegalArgumentException should have been thrown");
-        } catch (IllegalArgumentException ex) {
+            Assert.fail("IllegalArgumentException should have been thrown");
+        } catch (final IllegalArgumentException ex) {
             // expected
         }
     }
 
+    @Test
     public void testgetContent() throws Exception {
-        HttpEntity httpentity = new EntityTemplate(new ContentProducer() {
+        final HttpEntity httpentity = new EntityTemplate(new ContentProducer() {
 
+            @Override
             public void writeTo(final OutputStream outstream) throws IOException {
                 outstream.write('a');
             }
 
         });
-        try {
-            httpentity.getContent();
-            fail("UnsupportedOperationException should have been thrown");
-        } catch (UnsupportedOperationException ex) {
-            // expected
-        }
+        final InputStream instream = httpentity.getContent();
+        Assert.assertNotNull(instream);
+        final String s = EntityUtils.toString(httpentity);
+        Assert.assertEquals("a", s);
     }
 
 }
