@@ -33,20 +33,21 @@ import java.io.InputStream;
 import java.io.InterruptedIOException;
 import java.io.OutputStream;
 
+import org.apache.http.ConnectionClosedException;
+import org.apache.http.Consts;
 import org.apache.http.Header;
 import org.apache.http.MalformedChunkCodingException;
+import org.apache.http.MessageConstraintException;
 import org.apache.http.TruncatedChunkException;
+import org.apache.http.config.MessageConstraints;
 import org.apache.http.impl.SessionInputBufferMock;
 import org.apache.http.impl.SessionOutputBufferMock;
 import org.apache.http.io.SessionInputBuffer;
-import org.apache.http.util.EncodingUtils;
 import org.junit.Assert;
 import org.junit.Test;
 
 public class TestChunkCoding {
 
-    private static final String CONTENT_CHARSET = "ISO-8859-1";
-
     @Test
     public void testConstructors() throws Exception {
         try {
@@ -69,8 +70,7 @@ public class TestChunkCoding {
     @Test
     public void testChunkedInputStreamLargeBuffer() throws IOException {
         final ChunkedInputStream in = new ChunkedInputStream(
-                new SessionInputBufferMock(
-                        EncodingUtils.getBytes(CHUNKED_INPUT, CONTENT_CHARSET)));
+                new SessionInputBufferMock(CHUNKED_INPUT, Consts.ISO_8859_1));
         final byte[] buffer = new byte[300];
         final ByteArrayOutputStream out = new ByteArrayOutputStream();
         int len;
@@ -82,7 +82,7 @@ public class TestChunkCoding {
 
         in.close();
 
-        final String result = EncodingUtils.getString(out.toByteArray(), CONTENT_CHARSET);
+        final String result = new String(out.toByteArray(), Consts.ISO_8859_1);
         Assert.assertEquals(result, CHUNKED_RESULT);
 
         final Header[] footers = in.getFooters();
@@ -98,8 +98,7 @@ public class TestChunkCoding {
     @Test
     public void testChunkedInputStreamSmallBuffer() throws IOException {
         final ChunkedInputStream in = new ChunkedInputStream(
-                new SessionInputBufferMock(
-                            EncodingUtils.getBytes(CHUNKED_INPUT, CONTENT_CHARSET)));
+                new SessionInputBufferMock(CHUNKED_INPUT, Consts.ISO_8859_1));
 
         final byte[] buffer = new byte[7];
         final ByteArrayOutputStream out = new ByteArrayOutputStream();
@@ -112,7 +111,6 @@ public class TestChunkCoding {
 
         in.close();
 
-        EncodingUtils.getString(out.toByteArray(), CONTENT_CHARSET);
         final Header[] footers = in.getFooters();
         Assert.assertNotNull(footers);
         Assert.assertEquals(2, footers.length);
@@ -127,8 +125,7 @@ public class TestChunkCoding {
     public void testChunkedInputStreamOneByteRead() throws IOException {
         final String s = "5\r\n01234\r\n5\r\n56789\r\n0\r\n";
         final ChunkedInputStream in = new ChunkedInputStream(
-                new SessionInputBufferMock(
-                        EncodingUtils.getBytes(s, CONTENT_CHARSET)));
+                new SessionInputBufferMock(s, Consts.ISO_8859_1));
         int ch;
         int i = '0';
         while ((ch = in.read()) != -1) {
@@ -145,8 +142,7 @@ public class TestChunkCoding {
     public void testAvailable() throws IOException {
         final String s = "5\r\n12345\r\n0\r\n";
         final ChunkedInputStream in = new ChunkedInputStream(
-                new SessionInputBufferMock(
-                        EncodingUtils.getBytes(s, CONTENT_CHARSET)));
+                new SessionInputBufferMock(s, Consts.ISO_8859_1));
         Assert.assertEquals(0, in.available());
         in.read();
         Assert.assertEquals(4, in.available());
@@ -157,8 +153,7 @@ public class TestChunkCoding {
     public void testChunkedInputStreamClose() throws IOException {
         final String s = "5\r\n01234\r\n5\r\n56789\r\n0\r\n";
         final ChunkedInputStream in = new ChunkedInputStream(
-                new SessionInputBufferMock(
-                        EncodingUtils.getBytes(s, CONTENT_CHARSET)));
+                new SessionInputBufferMock(s, Consts.ISO_8859_1));
         in.close();
         in.close();
         try {
@@ -203,133 +198,115 @@ public class TestChunkCoding {
     }
 
     // Missing closing chunk
-    @Test
+    @Test(expected=ConnectionClosedException.class)
     public void testChunkedInputStreamNoClosingChunk() throws IOException {
         final String s = "5\r\n01234\r\n";
         final ChunkedInputStream in = new ChunkedInputStream(
-                new SessionInputBufferMock(
-                        EncodingUtils.getBytes(s, CONTENT_CHARSET)));
+                new SessionInputBufferMock(s, Consts.ISO_8859_1));
         final byte[] tmp = new byte[5];
         Assert.assertEquals(5, in.read(tmp));
-        Assert.assertEquals(-1, in.read());
+        in.read();
         in.close();
-}
+    }
+
+    // Truncated stream (missing closing CRLF)
+    @Test(expected=MalformedChunkCodingException.class)
+    public void testCorruptChunkedInputStreamTruncatedCRLF() throws IOException {
+        final String s = "5\r\n01234";
+        final ChunkedInputStream in = new ChunkedInputStream(
+                new SessionInputBufferMock(s, Consts.ISO_8859_1));
+        final byte[] tmp = new byte[5];
+        Assert.assertEquals(5, in.read(tmp));
+        in.read();
+        in.close();
+    }
 
     // Missing \r\n at the end of the first chunk
-    @Test
+    @Test(expected=MalformedChunkCodingException.class)
     public void testCorruptChunkedInputStreamMissingCRLF() throws IOException {
         final String s = "5\r\n012345\r\n56789\r\n0\r\n";
         final InputStream in = new ChunkedInputStream(
-                new SessionInputBufferMock(
-                        EncodingUtils.getBytes(s, CONTENT_CHARSET)));
+                new SessionInputBufferMock(s, Consts.ISO_8859_1));
         final byte[] buffer = new byte[300];
         final ByteArrayOutputStream out = new ByteArrayOutputStream();
         int len;
-        try {
-            while ((len = in.read(buffer)) > 0) {
-                out.write(buffer, 0, len);
-            }
-            Assert.fail("MalformedChunkCodingException should have been thrown");
-        } catch(final MalformedChunkCodingException e) {
-            /* expected exception */
+        while ((len = in.read(buffer)) > 0) {
+            out.write(buffer, 0, len);
         }
+        in.close();
     }
 
     // Missing LF
-    @Test
+    @Test(expected=MalformedChunkCodingException.class)
     public void testCorruptChunkedInputStreamMissingLF() throws IOException {
         final String s = "5\r01234\r\n5\r\n56789\r\n0\r\n";
         final InputStream in = new ChunkedInputStream(
-                new SessionInputBufferMock(
-                        EncodingUtils.getBytes(s, CONTENT_CHARSET)));
-        try {
-            in.read();
-            Assert.fail("MalformedChunkCodingException should have been thrown");
-        } catch(final MalformedChunkCodingException e) {
-            /* expected exception */
-        }
+                new SessionInputBufferMock(s, Consts.ISO_8859_1));
+        in.read();
         in.close();
-}
+    }
 
     // Invalid chunk size
-    @Test
+    @Test(expected = MalformedChunkCodingException.class)
     public void testCorruptChunkedInputStreamInvalidSize() throws IOException {
         final String s = "whatever\r\n01234\r\n5\r\n56789\r\n0\r\n";
         final InputStream in = new ChunkedInputStream(
-                new SessionInputBufferMock(
-                        EncodingUtils.getBytes(s, CONTENT_CHARSET)));
-        try {
-            in.read();
-            Assert.fail("MalformedChunkCodingException should have been thrown");
-        } catch(final MalformedChunkCodingException e) {
-            /* expected exception */
-        }
-        try {
-            in.close();
-        } catch (TruncatedChunkException expected) {
-        }
-}
+                new SessionInputBufferMock(s, Consts.ISO_8859_1));
+        in.read();
+        in.close();
+    }
 
     // Negative chunk size
-    @Test
+    @Test(expected = MalformedChunkCodingException.class)
     public void testCorruptChunkedInputStreamNegativeSize() throws IOException {
         final String s = "-5\r\n01234\r\n5\r\n56789\r\n0\r\n";
         final InputStream in = new ChunkedInputStream(
-                new SessionInputBufferMock(
-                        EncodingUtils.getBytes(s, CONTENT_CHARSET)));
-        try {
-            in.read();
-            Assert.fail("MalformedChunkCodingException should have been thrown");
-        } catch(final MalformedChunkCodingException e) {
-            /* expected exception */
-        }
-        try {
-            in.close();
-        } catch (TruncatedChunkException expected) {
-        }
-}
+                new SessionInputBufferMock(s, Consts.ISO_8859_1));
+        in.read();
+        in.close();
+    }
 
     // Truncated chunk
-    @Test
+    @Test(expected = TruncatedChunkException.class)
     public void testCorruptChunkedInputStreamTruncatedChunk() throws IOException {
         final String s = "3\r\n12";
         final InputStream in = new ChunkedInputStream(
-                new SessionInputBufferMock(
-                        EncodingUtils.getBytes(s, CONTENT_CHARSET)));
+                new SessionInputBufferMock(s, Consts.ISO_8859_1));
         final byte[] buffer = new byte[300];
         Assert.assertEquals(2, in.read(buffer));
-        try {
-            in.read(buffer);
-            Assert.fail("MalformedChunkCodingException should have been thrown");
-        } catch(final MalformedChunkCodingException e) {
-            /* expected exception */
-        }
+        in.read(buffer);
         in.close();
-}
+    }
 
     // Invalid footer
-    @Test
+    @Test(expected = MalformedChunkCodingException.class)
     public void testCorruptChunkedInputStreamInvalidFooter() throws IOException {
         final String s = "1\r\n0\r\n0\r\nstuff\r\n";
         final InputStream in = new ChunkedInputStream(
-                new SessionInputBufferMock(
-                        EncodingUtils.getBytes(s, CONTENT_CHARSET)));
+                new SessionInputBufferMock(s, Consts.ISO_8859_1));
+        in.read();
+        in.read();
+        in.close();
+    }
+
+    @Test
+    public void testCorruptChunkedInputStreamClose() throws IOException {
+        final String s = "whatever\r\n01234\r\n5\r\n56789\r\n0\r\n";
+        final InputStream in = new ChunkedInputStream(
+                new SessionInputBufferMock(s, Consts.ISO_8859_1));
         try {
             in.read();
-            in.read();
-            Assert.fail("MalformedChunkCodingException should have been thrown");
-        } catch(final MalformedChunkCodingException e) {
-            /* expected exception */
+            Assert.fail("MalformedChunkCodingException expected");
+        } catch (MalformedChunkCodingException ex) {
         }
         in.close();
-}
+    }
 
     @Test
     public void testEmptyChunkedInputStream() throws IOException {
         final String input = "0\r\n";
         final InputStream in = new ChunkedInputStream(
-                new SessionInputBufferMock(
-                        EncodingUtils.getBytes(input, CONTENT_CHARSET)));
+                new SessionInputBufferMock(input, Consts.ISO_8859_1));
         final byte[] buffer = new byte[300];
         final ByteArrayOutputStream out = new ByteArrayOutputStream();
         int len;
@@ -338,21 +315,42 @@ public class TestChunkCoding {
         }
         Assert.assertEquals(0, out.size());
         in.close();
-}
+    }
+
+    @Test
+    public void testTooLongChunkHeader() throws IOException {
+        final String input = "5; and some very looooong commend\r\n12345\r\n0\r\n";
+        final InputStream in1 = new ChunkedInputStream(
+                new SessionInputBufferMock(input, MessageConstraints.DEFAULT, Consts.ISO_8859_1));
+        final byte[] buffer = new byte[300];
+        Assert.assertEquals(5, in1.read(buffer));
+        in1.close();
+
+        final InputStream in2 = new ChunkedInputStream(
+                new SessionInputBufferMock(input, MessageConstraints.lineLen(10), Consts.ISO_8859_1));
+        try {
+            in2.read(buffer);
+            Assert.fail("MessageConstraintException expected");
+        } catch (MessageConstraintException ex) {
+        } finally {
+            try {
+                in2.close();
+            } catch (MessageConstraintException ex) {
+            }
+        }
+    }
 
     @Test
     public void testChunkedConsistence() throws IOException {
         final String input = "76126;27823abcd;:q38a-\nkjc\rk%1ad\tkh/asdui\r\njkh+?\\suweb";
         final ByteArrayOutputStream buffer = new ByteArrayOutputStream();
         final OutputStream out = new ChunkedOutputStream(2048, new SessionOutputBufferMock(buffer));
-        out.write(EncodingUtils.getBytes(input, CONTENT_CHARSET));
+        out.write(input.getBytes(Consts.ISO_8859_1));
         out.flush();
         out.close();
         out.close();
         buffer.close();
-        final InputStream in = new ChunkedInputStream(
-                new SessionInputBufferMock(
-                        buffer.toByteArray()));
+        final InputStream in = new ChunkedInputStream(new SessionInputBufferMock(buffer.toByteArray()));
 
         final byte[] d = new byte[10];
         final ByteArrayOutputStream result = new ByteArrayOutputStream();
@@ -361,7 +359,7 @@ public class TestChunkCoding {
             result.write(d, 0, len);
         }
 
-        final String output = EncodingUtils.getString(result.toByteArray(), CONTENT_CHARSET);
+        final String output = new String(result.toByteArray(), Consts.ISO_8859_1);
         Assert.assertEquals(input, output);
         in.close();
 }
@@ -456,7 +454,7 @@ public class TestChunkCoding {
     public void testResumeOnSocketTimeoutInData() throws IOException {
         final String s = "5\r\n01234\r\n5\r\n5\0006789\r\na\r\n0123\000456789\r\n0\r\n";
         final SessionInputBuffer sessbuf = new SessionInputBufferMock(
-                new TimeoutByteArrayInputStream(s.getBytes("ISO-8859-1")), 16);
+                new TimeoutByteArrayInputStream(s.getBytes(Consts.ISO_8859_1)), 16);
         final InputStream in = new ChunkedInputStream(sessbuf);
 
         final byte[] tmp = new byte[3];
@@ -484,7 +482,7 @@ public class TestChunkCoding {
     public void testResumeOnSocketTimeoutInChunk() throws IOException {
         final String s = "5\000\r\000\n\00001234\r\n\0005\r\n56789\r\na\r\n0123456789\r\n\0000\r\n";
         final SessionInputBuffer sessbuf = new SessionInputBufferMock(
-                new TimeoutByteArrayInputStream(s.getBytes("ISO-8859-1")), 16);
+                new TimeoutByteArrayInputStream(s.getBytes(Consts.ISO_8859_1)), 16);
         final InputStream in = new ChunkedInputStream(sessbuf);
 
         final byte[] tmp = new byte[3];
