@@ -28,13 +28,13 @@
 package org.apache.http.impl.io;
 
 import java.io.ByteArrayOutputStream;
-import java.io.IOException;
 import java.nio.charset.CharacterCodingException;
 import java.nio.charset.CharsetDecoder;
 import java.nio.charset.CharsetEncoder;
 import java.nio.charset.CodingErrorAction;
 
 import org.apache.http.Consts;
+import org.apache.http.MessageConstraintException;
 import org.apache.http.config.MessageConstraints;
 import org.apache.http.impl.SessionInputBufferMock;
 import org.apache.http.impl.SessionOutputBufferMock;
@@ -137,7 +137,7 @@ public class TestSessionInOutBuffers {
         }
         final String s1 = buffer.toString();
         buffer.append("\r\n");
-        outbuffer.write(buffer.toString().getBytes("US-ASCII"));
+        outbuffer.write(buffer.toString().getBytes(Consts.ASCII));
         outbuffer.flush();
         bytesWritten = outbuffer.getMetrics().getBytesTransferred();
         Assert.assertEquals(8 + 14 +2, bytesWritten);
@@ -148,7 +148,7 @@ public class TestSessionInOutBuffers {
         }
         final String s2 = buffer.toString();
         buffer.append("\r\n");
-        outbuffer.write(buffer.toString().getBytes("US-ASCII"));
+        outbuffer.write(buffer.toString().getBytes(Consts.ASCII));
         outbuffer.flush();
         bytesWritten = outbuffer.getMetrics().getBytesTransferred();
         Assert.assertEquals(8 + 14 + 2 + 15 + 2 , bytesWritten);
@@ -159,7 +159,7 @@ public class TestSessionInOutBuffers {
         }
         final String s3 = buffer.toString();
         buffer.append("\r\n");
-        outbuffer.write(buffer.toString().getBytes("US-ASCII"));
+        outbuffer.write(buffer.toString().getBytes(Consts.ASCII));
         outbuffer.flush();
         bytesWritten = outbuffer.getMetrics().getBytesTransferred();
         Assert.assertEquals(8 + 14 + 2 + 15 + 2 + 16 + 2, bytesWritten);
@@ -336,10 +336,10 @@ public class TestSessionInOutBuffers {
         outbuffer.write(1);
         outbuffer.write(2);
         outbuffer.write(new byte[] {1, 2});
-        outbuffer.write(new byte[] {3, 4});
+        outbuffer.write(new byte[]{3, 4});
         outbuffer.flush();
         Mockito.verify(outstream, Mockito.times(1)).write(
-                Mockito.<byte []>any(), Mockito.anyInt(), Mockito.anyInt());
+                Mockito.<byte[]>any(), Mockito.anyInt(), Mockito.anyInt());
         Mockito.verify(outstream, Mockito.never()).write(Mockito.anyInt());
     }
 
@@ -350,7 +350,7 @@ public class TestSessionInOutBuffers {
         outbuffer.write(1);
         outbuffer.write(2);
         outbuffer.write(new byte[] {1, 2});
-        outbuffer.write(new byte[] {3, 4});
+        outbuffer.write(new byte[]{3, 4});
         Mockito.verify(outstream, Mockito.times(2)).write(
                 Mockito.<byte []>any(), Mockito.anyInt(), Mockito.anyInt());
         Mockito.verify(outstream, Mockito.times(2)).write(Mockito.anyInt());
@@ -358,13 +358,13 @@ public class TestSessionInOutBuffers {
 
     @Test
     public void testLineLimit() throws Exception {
-        final String s = "a very looooooooooooooooooooooooooooooooooooooong line\r\n     ";
-        final byte[] tmp = s.getBytes("US-ASCII");
+        final String s = "a very looooooooooooooooooooooooooooooooooooooooooong line\r\n";
+        final byte[] tmp = s.getBytes(Consts.ASCII);
         // no limit
         final SessionInputBufferMock inbuffer1 = new SessionInputBufferMock(tmp, 5,
                 MessageConstraints.DEFAULT);
         Assert.assertNotNull(inbuffer1.readLine());
-        long bytesRead = inbuffer1.getMetrics().getBytesTransferred();
+        final long bytesRead = inbuffer1.getMetrics().getBytesTransferred();
         Assert.assertEquals(60, bytesRead);
 
         // 15 char limit
@@ -372,18 +372,36 @@ public class TestSessionInOutBuffers {
                 MessageConstraints.lineLen(15));
         try {
             inbuffer2.readLine();
-            Assert.fail("IOException should have been thrown");
-        } catch (final IOException ex) {
-            // expected
-            bytesRead = inbuffer2.getMetrics().getBytesTransferred();
-            Assert.assertEquals(20, bytesRead);
+            Assert.fail("MessageConstraintException expected");
+        } catch (MessageConstraintException ex) {
+        }
+    }
+
+    @Test
+    public void testLineLimit2() throws Exception {
+        final String s = "just a line\r\n";
+        final byte[] tmp = s.getBytes(Consts.ASCII);
+        // no limit
+        final SessionInputBufferMock inbuffer1 = new SessionInputBufferMock(tmp, 25,
+                MessageConstraints.DEFAULT);
+        Assert.assertNotNull(inbuffer1.readLine());
+        final long bytesRead = inbuffer1.getMetrics().getBytesTransferred();
+        Assert.assertEquals(13, bytesRead);
+
+        // 10 char limit
+        final SessionInputBufferMock inbuffer2 = new SessionInputBufferMock(tmp, 25,
+                MessageConstraints.lineLen(10));
+        try {
+            inbuffer2.readLine();
+            Assert.fail("MessageConstraintException expected");
+        } catch (MessageConstraintException ex) {
         }
     }
 
     @Test
     public void testReadLineFringeCase1() throws Exception {
         final String s = "abc\r\n";
-        final byte[] tmp = s.getBytes("US-ASCII");
+        final byte[] tmp = s.getBytes(Consts.ASCII);
         final SessionInputBufferMock inbuffer1 = new SessionInputBufferMock(tmp, 128);
         Assert.assertEquals('a', inbuffer1.read());
         Assert.assertEquals('b', inbuffer1.read());
@@ -433,9 +451,9 @@ public class TestSessionInOutBuffers {
         }
         outbuffer.flush();
         final long bytesWritten = outbuffer.getMetrics().getBytesTransferred();
-        final long expected = ((s1.getBytes("UTF-8").length + 2)+
-                (s2.getBytes("UTF-8").length + 2) +
-                (s3.getBytes("UTF-8").length + 2)) * 10;
+        final long expected = ((s1.getBytes(Consts.UTF_8).length + 2)+
+                (s2.getBytes(Consts.UTF_8).length + 2) +
+                (s3.getBytes(Consts.UTF_8).length + 2)) * 10;
         Assert.assertEquals(expected, bytesWritten);
 
         final SessionInputBufferMock inbuffer = new SessionInputBufferMock(
@@ -495,7 +513,7 @@ public class TestSessionInOutBuffers {
         outbuffer.writeLine(chbuffer);
         outbuffer.flush();
         final long bytesWritten = outbuffer.getMetrics().getBytesTransferred();
-        final long expected = ((s1.toString().getBytes(Consts.ISO_8859_1.name()).length + 2)) * 10 + 2;
+        final long expected = ((s1.toString().getBytes(Consts.ISO_8859_1).length + 2)) * 10 + 2;
         Assert.assertEquals(expected, bytesWritten);
 
         final SessionInputBufferMock inbuffer = new SessionInputBufferMock(
@@ -554,7 +572,7 @@ public class TestSessionInOutBuffers {
 
     @Test(expected=CharacterCodingException.class)
     public void testMalformedInputActionReport() throws Exception {
-        final byte[] tmp = constructString(SWISS_GERMAN_HELLO).getBytes(Consts.ISO_8859_1.name());
+        final byte[] tmp = constructString(SWISS_GERMAN_HELLO).getBytes(Consts.ISO_8859_1);
         final CharsetDecoder decoder = Consts.UTF_8.newDecoder();
         decoder.onMalformedInput(CodingErrorAction.REPORT);
         decoder.onUnmappableCharacter(CodingErrorAction.IGNORE);
@@ -564,7 +582,7 @@ public class TestSessionInOutBuffers {
 
     @Test
     public void testMalformedInputActionReplace() throws Exception {
-        final byte[] tmp = constructString(SWISS_GERMAN_HELLO).getBytes(Consts.ISO_8859_1.name());
+        final byte[] tmp = constructString(SWISS_GERMAN_HELLO).getBytes(Consts.ISO_8859_1);
         final CharsetDecoder decoder = Consts.UTF_8.newDecoder();
         decoder.onMalformedInput(CodingErrorAction.REPLACE);
         decoder.onUnmappableCharacter(CodingErrorAction.IGNORE);
@@ -575,7 +593,7 @@ public class TestSessionInOutBuffers {
 
     @Test
     public void testMalformedInputActionIgnore() throws Exception {
-        final byte[] tmp = constructString(SWISS_GERMAN_HELLO).getBytes(Consts.ISO_8859_1.name());
+        final byte[] tmp = constructString(SWISS_GERMAN_HELLO).getBytes(Consts.ISO_8859_1);
         final CharsetDecoder decoder = Consts.UTF_8.newDecoder();
         decoder.onMalformedInput(CodingErrorAction.IGNORE);
         decoder.onUnmappableCharacter(CodingErrorAction.IGNORE);
