@@ -32,7 +32,6 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.OutputStream;
-import java.io.UnsupportedEncodingException;
 import java.nio.charset.Charset;
 import java.util.ArrayList;
 import java.util.List;
@@ -120,6 +119,7 @@ public class TestSyncHttp {
         // Initialize the server-side request handler
         this.server.registerHandler("*", new HttpRequestHandler() {
 
+            @Override
             public void handle(
                     final HttpRequest request,
                     final HttpResponse response,
@@ -196,6 +196,7 @@ public class TestSyncHttp {
         // Initialize the server-side request handler
         this.server.registerHandler("*", new HttpRequestHandler() {
 
+            @Override
             public void handle(
                     final HttpRequest request,
                     final HttpResponse response,
@@ -278,6 +279,7 @@ public class TestSyncHttp {
         // Initialize the server-side request handler
         this.server.registerHandler("*", new HttpRequestHandler() {
 
+            @Override
             public void handle(
                     final HttpRequest request,
                     final HttpResponse response,
@@ -359,6 +361,7 @@ public class TestSyncHttp {
         // Initialize the server-side request handler
         this.server.registerHandler("*", new HttpRequestHandler() {
 
+            @Override
             public void handle(
                     final HttpRequest request,
                     final HttpResponse response,
@@ -444,6 +447,7 @@ public class TestSyncHttp {
         // Initialize the server-side request handler
         this.server.registerHandler("*", new HttpRequestHandler() {
 
+            @Override
             public void handle(
                     final HttpRequest request,
                     final HttpResponse response,
@@ -518,6 +522,7 @@ public class TestSyncHttp {
         // Initialize the server-side request handler
         this.server.registerHandler("*", new HttpRequestHandler() {
 
+            @Override
             public void handle(
                     final HttpRequest request,
                     final HttpResponse response,
@@ -531,6 +536,7 @@ public class TestSyncHttp {
 
         this.server.setExpectationVerifier(new HttpExpectationVerifier() {
 
+            @Override
             public void verify(
                     final HttpRequest request,
                     final HttpResponse response,
@@ -607,34 +613,32 @@ public class TestSyncHttp {
             super();
             final Charset cs = charset != null ? charset : Charset.forName("US-ASCII");
             byte[] b;
-            // Java 6 only:
-            // b = content.getBytes(charset);
-            // Java 5 OK:
-            try {
-                b = content.getBytes(cs.name());
-            } catch (final UnsupportedEncodingException ex) {
-                b = content.getBytes();
-            }
+            b = content.getBytes(cs);
             this.raw = b;
             this.n = n;
         }
 
+        @Override
         public InputStream getContent() throws IOException, IllegalStateException {
             throw new IllegalStateException("This method is not implemented");
         }
 
+        @Override
         public long getContentLength() {
             return (this.raw.length + 2) * this.n;
         }
 
+        @Override
         public boolean isRepeatable() {
             return true;
         }
 
+        @Override
         public boolean isStreaming() {
             return false;
         }
 
+        @Override
         public void writeTo(final OutputStream outstream) throws IOException {
             for (int i = 0; i < this.n; i++) {
                 outstream.write(this.raw);
@@ -672,6 +676,7 @@ public class TestSyncHttp {
         // Initialize the server-side request handler
         this.server.registerHandler("*", new HttpRequestHandler() {
 
+            @Override
             public void handle(
                     final HttpRequest request,
                     final HttpResponse response,
@@ -762,6 +767,7 @@ public class TestSyncHttp {
     public void testHttpPostNoEntity() throws Exception {
         this.server.registerHandler("*", new HttpRequestHandler() {
 
+            @Override
             public void handle(
                     final HttpRequest request,
                     final HttpResponse response,
@@ -807,6 +813,7 @@ public class TestSyncHttp {
     public void testHttpPostNoContentLength() throws Exception {
         this.server.registerHandler("*", new HttpRequestHandler() {
 
+            @Override
             public void handle(
                     final HttpRequest request,
                     final HttpResponse response,
@@ -859,6 +866,7 @@ public class TestSyncHttp {
     public void testHttpPostIdentity() throws Exception {
         this.server.registerHandler("*", new HttpRequestHandler() {
 
+            @Override
             public void handle(
                     final HttpRequest request,
                     final HttpResponse response,
@@ -894,6 +902,7 @@ public class TestSyncHttp {
                     new HttpRequestInterceptor[] {
                             new HttpRequestInterceptor() {
 
+                                @Override
                                 public void process(
                                         final HttpRequest request,
                                         final HttpContext context) throws HttpException, IOException {
@@ -922,6 +931,7 @@ public class TestSyncHttp {
         // Initialize the server-side request handler
         this.server.registerHandler("*", new HttpRequestHandler() {
 
+            @Override
             public void handle(
                     final HttpRequest request,
                     final HttpResponse response,
