@@ -29,27 +29,21 @@ package org.apache.http.message;
 
 import java.util.NoSuchElementException;
 
-import junit.framework.TestCase;
-
 import org.apache.http.Header;
 import org.apache.http.HeaderIterator;
 import org.apache.http.ParseException;
 import org.apache.http.TokenIterator;
+import org.junit.Assert;
+import org.junit.Test;
 
 
 /**
  * Tests for {@link BasicTokenIterator}.
  *
  */
-public class TestBasicTokenIterator extends TestCase {
-
-    // ------------------------------------------------------------ Constructor
-    public TestBasicTokenIterator(String testName) {
-        super(testName);
-    }
-
-    // ------------------------------------------------------- TestCase Methods
+public class TestBasicTokenIterator {
 
+    @Test
     public void testSingleHeader() {
         Header[] headers = new Header[]{
             new BasicHeader("Name", "token0,token1, token2 , token3")
@@ -57,15 +51,15 @@ public class TestBasicTokenIterator extends TestCase {
         HeaderIterator hit = new BasicHeaderIterator(headers, null);
         TokenIterator  ti  = new BasicTokenIterator(hit);
 
-        assertTrue(ti.hasNext());
-        assertEquals("token0", "token0", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token1", "token1", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token2", "token2", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token3", "token3", ti.nextToken());
-        assertFalse(ti.hasNext());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token0", "token0", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token1", "token1", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token2", "token2", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token3", "token3", ti.nextToken());
+        Assert.assertFalse(ti.hasNext());
 
 
         headers = new Header[]{
@@ -74,14 +68,15 @@ public class TestBasicTokenIterator extends TestCase {
         hit = new BasicHeaderIterator(headers, null);
         ti  = new BasicTokenIterator(hit);
 
-        assertTrue(ti.hasNext());
-        assertEquals("token0", "token0", ti.nextToken());
-        assertFalse(ti.hasNext());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token0", "token0", ti.nextToken());
+        Assert.assertFalse(ti.hasNext());
     }
 
 
+    @Test
     public void testMultiHeader() {
-        Header[] headers = new Header[]{
+        final Header[] headers = new Header[]{
             new BasicHeader("Name", "token0,token1"),
             new BasicHeader("Name", ""),
             new BasicHeader("Name", "token2"),
@@ -90,25 +85,26 @@ public class TestBasicTokenIterator extends TestCase {
             new BasicHeader("Name", ","),
             new BasicHeader("Name", "token4"),
         };
-        HeaderIterator hit = new BasicHeaderIterator(headers, null);
-        TokenIterator  ti  = new BasicTokenIterator(hit);
+        final HeaderIterator hit = new BasicHeaderIterator(headers, null);
+        final TokenIterator  ti  = new BasicTokenIterator(hit);
 
-        assertTrue(ti.hasNext());
-        assertEquals("token0", "token0", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token1", "token1", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token2", "token2", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token3", "token3", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token4", "token4", ti.nextToken());
-        assertFalse(ti.hasNext());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token0", "token0", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token1", "token1", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token2", "token2", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token3", "token3", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token4", "token4", ti.nextToken());
+        Assert.assertFalse(ti.hasNext());
     }
 
 
+    @Test
     public void testEmpty() {
-        Header[] headers = new Header[]{
+        final Header[] headers = new Header[]{
             new BasicHeader("Name", " "),
             new BasicHeader("Name", ""),
             new BasicHeader("Name", ","),
@@ -117,18 +113,19 @@ public class TestBasicTokenIterator extends TestCase {
         HeaderIterator hit = new BasicHeaderIterator(headers, null);
         TokenIterator  ti  = new BasicTokenIterator(hit);
 
-        assertFalse(ti.hasNext());
+        Assert.assertFalse(ti.hasNext());
 
 
         hit = new BasicHeaderIterator(headers, "empty");
         ti  = new BasicTokenIterator(hit);
 
-        assertFalse(ti.hasNext());
+        Assert.assertFalse(ti.hasNext());
     }
 
 
+    @Test
     public void testValueStart() {
-        Header[] headers = new Header[]{
+        final Header[] headers = new Header[]{
             new BasicHeader("Name", "token0"),
             new BasicHeader("Name", " token1"),
             new BasicHeader("Name", ",token2"),
@@ -136,27 +133,28 @@ public class TestBasicTokenIterator extends TestCase {
             new BasicHeader("Name", ", token4"),
             new BasicHeader("Name", " , token5"),
         };
-        HeaderIterator hit = new BasicHeaderIterator(headers, null);
-        TokenIterator  ti  = new BasicTokenIterator(hit);
+        final HeaderIterator hit = new BasicHeaderIterator(headers, null);
+        final TokenIterator  ti  = new BasicTokenIterator(hit);
 
-        assertTrue(ti.hasNext());
-        assertEquals("token0", "token0", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token1", "token1", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token2", "token2", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token3", "token3", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token4", "token4", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token5", "token5", ti.nextToken());
-        assertFalse(ti.hasNext());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token0", "token0", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token1", "token1", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token2", "token2", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token3", "token3", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token4", "token4", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token5", "token5", ti.nextToken());
+        Assert.assertFalse(ti.hasNext());
     }
 
 
+    @Test
     public void testValueEnd() {
-        Header[] headers = new Header[]{
+        final Header[] headers = new Header[]{
             new BasicHeader("Name", "token0"),
             new BasicHeader("Name", "token1 "),
             new BasicHeader("Name", "token2,"),
@@ -164,41 +162,43 @@ public class TestBasicTokenIterator extends TestCase {
             new BasicHeader("Name", "token4, "),
             new BasicHeader("Name", "token5 , "),
         };
-        HeaderIterator hit = new BasicHeaderIterator(headers, null);
-        TokenIterator  ti  = new BasicTokenIterator(hit);
+        final HeaderIterator hit = new BasicHeaderIterator(headers, null);
+        final TokenIterator  ti  = new BasicTokenIterator(hit);
 
-        assertTrue(ti.hasNext());
-        assertEquals("token0", "token0", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token1", "token1", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token2", "token2", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token3", "token3", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token4", "token4", ti.nextToken());
-        assertTrue(ti.hasNext());
-        assertEquals("token5", "token5", ti.nextToken());
-        assertFalse(ti.hasNext());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token0", "token0", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token1", "token1", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token2", "token2", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token3", "token3", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token4", "token4", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token5", "token5", ti.nextToken());
+        Assert.assertFalse(ti.hasNext());
     }
 
 
+    @Test
     public void testTokenChar() {
-        Header[] headers = new Header[]{
+        final Header[] headers = new Header[]{
             new BasicHeader("Name", "token0")
         };
-        HeaderIterator     hit = new BasicHeaderIterator(headers, null);
-        BasicTokenIterator bti = new BasicTokenIterator(hit);
+        final HeaderIterator     hit = new BasicHeaderIterator(headers, null);
+        final BasicTokenIterator bti = new BasicTokenIterator(hit);
 
-        assertTrue ("letter"   , bti.isTokenChar('j'));
-        assertFalse("control"  , bti.isTokenChar('\b'));
-        assertFalse("separator", bti.isTokenChar('?'));
-        assertTrue ("other"    , bti.isTokenChar('-'));
+        Assert.assertTrue ("letter"   , bti.isTokenChar('j'));
+        Assert.assertFalse("control"  , bti.isTokenChar('\b'));
+        Assert.assertFalse("separator", bti.isTokenChar('?'));
+        Assert.assertTrue ("other"    , bti.isTokenChar('-'));
     }
 
 
+    @Test
     public void testInvalid() {
-        Header[] headers = new Header[]{
+        final Header[] headers = new Header[]{
             new BasicHeader("in", "token0=token1"),
             new BasicHeader("no", "token0 token1"),
             new BasicHeader("pre", "<token0,token1"),
@@ -208,11 +208,11 @@ public class TestBasicTokenIterator extends TestCase {
         TokenIterator  ti  = new BasicTokenIterator(hit);
 
         // constructor located token0
-        assertTrue(ti.hasNext());
+        Assert.assertTrue(ti.hasNext());
         try {
             ti.nextToken();
-            fail("invalid infix character not detected");
-        } catch (ParseException px) {
+            Assert.fail("invalid infix character not detected");
+        } catch (final ParseException px) {
             // expected
         }
 
@@ -220,11 +220,11 @@ public class TestBasicTokenIterator extends TestCase {
         // constructor located token0
         hit = new BasicHeaderIterator(headers, "no");
         ti  = new BasicTokenIterator(hit);
-        assertTrue(ti.hasNext());
+        Assert.assertTrue(ti.hasNext());
         try {
             ti.nextToken();
-            fail("missing token separator not detected");
-        } catch (ParseException px) {
+            Assert.fail("missing token separator not detected");
+        } catch (final ParseException px) {
             // expected
         }
 
@@ -233,8 +233,8 @@ public class TestBasicTokenIterator extends TestCase {
         hit = new BasicHeaderIterator(headers, "pre");
         try {
             new BasicTokenIterator(hit);
-            fail("invalid prefix character not detected");
-        } catch (ParseException px) {
+            Assert.fail("invalid prefix character not detected");
+        } catch (final ParseException px) {
             // expected
         }
 
@@ -242,80 +242,82 @@ public class TestBasicTokenIterator extends TestCase {
         hit = new BasicHeaderIterator(headers, "post");
         ti  = new BasicTokenIterator(hit);
 
-        assertTrue(ti.hasNext());
-        assertEquals("token0", "token0", ti.nextToken());
-        assertTrue(ti.hasNext());
+        Assert.assertTrue(ti.hasNext());
+        Assert.assertEquals("token0", "token0", ti.nextToken());
+        Assert.assertTrue(ti.hasNext());
         // failure after the last must not go unpunished
         try {
             ti.nextToken();
-            fail("invalid postfix character not detected");
-        } catch (ParseException px) {
+            Assert.fail("invalid postfix character not detected");
+        } catch (final ParseException px) {
             // expected
         }
     }
 
 
+    @Test
     public void testWrongPublic() {
 
         try {
             new BasicTokenIterator(null);
-            fail("null argument not detected");
-        } catch (IllegalArgumentException iax) {
+            Assert.fail("null argument not detected");
+        } catch (final IllegalArgumentException iax) {
             // expected
         }
 
-        Header[] headers = new Header[]{
+        final Header[] headers = new Header[]{
             new BasicHeader("Name", " "),
             new BasicHeader("Name", ""),
             new BasicHeader("Name", ","),
             new BasicHeader("Name", " ,, "),
         };
-        HeaderIterator hit = new BasicHeaderIterator(headers, null);
-        TokenIterator  ti  = new BasicTokenIterator(hit);
+        final HeaderIterator hit = new BasicHeaderIterator(headers, null);
+        final TokenIterator  ti  = new BasicTokenIterator(hit);
 
         try {
             // call next() instead of nextToken() to get that covered, too
             ti.next();
-            fail("next after end not detected");
-        } catch (NoSuchElementException nsx) {
+            Assert.fail("next after end not detected");
+        } catch (final NoSuchElementException nsx) {
             // expected
         }
 
         try {
             ti.remove();
-            fail("unsupported remove not detected");
-        } catch (UnsupportedOperationException uox) {
+            Assert.fail("unsupported remove not detected");
+        } catch (final UnsupportedOperationException uox) {
             // expected
         }
     }
 
 
+    @Test
     public void testWrongProtected() {
 
-        Header[] headers = new Header[]{
+        final Header[] headers = new Header[]{
             new BasicHeader("Name", "token1,token2")
         };
-        HeaderIterator     hit = new BasicHeaderIterator(headers, null);
-        BasicTokenIterator bti = new BasicTokenIterator(hit);
+        final HeaderIterator     hit = new BasicHeaderIterator(headers, null);
+        final BasicTokenIterator bti = new BasicTokenIterator(hit);
 
         try {
             bti.findTokenStart(-1);
-            fail("tokenStart: negative index not detected");
-        } catch (IllegalArgumentException iax) {
+            Assert.fail("tokenStart: negative index not detected");
+        } catch (final IllegalArgumentException iax) {
             // expected
         }
 
         try {
             bti.findTokenSeparator(-1);
-            fail("tokenSeparator: negative index not detected");
-        } catch (IllegalArgumentException iax) {
+            Assert.fail("tokenSeparator: negative index not detected");
+        } catch (final IllegalArgumentException iax) {
             // expected
         }
 
         try {
             bti.findTokenEnd(-1);
-            fail("tokenEnd: negative index not detected");
-        } catch (IllegalArgumentException iax) {
+            Assert.fail("tokenEnd: negative index not detected");
+        } catch (final IllegalArgumentException iax) {
             // expected
         }
     }
